#ifndef _SETJMP_H_
#define _SETJMP_H_
#ifndef _jmp_buf_def_
#define _jmp_buf_def_
typedef struct _jmp_buf{
  int _jb[12];
} jmp_buf[1];
#endif
extern int setjmp(jmp_buf);
#endif
/* This is a C header file to be used by the output of the Cyclone to
   C translator.  The corresponding definitions are in file
   lib/runtime_cyc.c
*/
#ifndef _CYC_INCLUDE_H_
#define _CYC_INCLUDE_H_

#ifdef NO_CYC_PREFIX
#define ADD_PREFIX(x) x
#else
#define ADD_PREFIX(x) Cyc_##x
#endif

#ifndef offsetof
/* should be size_t, but int is fine. */
#define offsetof(t,n) ((int)(&(((t *)0)->n)))
#endif

/* Tagged arrays */
struct _dyneither_ptr {
  unsigned char *curr; 
  unsigned char *base; 
  unsigned char *last_plus_one; 
};  

/* Discriminated Unions */
struct _xtunion_struct { char *tag; };

/* Need one of these per thread (we don't have threads)
   The runtime maintains a stack that contains either _handler_cons
   structs or _RegionHandle structs.  The tag is 0 for a handler_cons
   and 1 for a region handle.  */
struct _RuntimeStack {
  int tag; /* 0 for an exception handler, 1 for a region handle */
  struct _RuntimeStack *next;
};

/* Regions */
struct _RegionPage {
#ifdef CYC_REGION_PROFILE
  unsigned total_bytes;
  unsigned free_bytes;
#endif
  struct _RegionPage *next;
  char data[1];  /*FJS: used to be size 0, but that's forbidden in ansi c*/
};

struct _RegionHandle {
  struct _RuntimeStack s;
  struct _RegionPage *curr;
  char               *offset;
  char               *last_plus_one;
  struct _DynRegionHandle *sub_regions;
#ifdef CYC_REGION_PROFILE
  const char         *name;
#endif
};

struct _DynRegionFrame {
  struct _RuntimeStack s;
  struct _DynRegionHandle *x;
};

// A dynamic region is just a region handle.  We have the
// wrapper struct for type abstraction reasons.
struct Cyc_Core_DynamicRegion {
  struct _RegionHandle h;
};

extern struct _RegionHandle _new_region(const char *);
extern void * _region_malloc(struct _RegionHandle *, unsigned);
extern void * _region_calloc(struct _RegionHandle *, unsigned t, unsigned n);
extern void   _free_region(struct _RegionHandle *);
extern void   _reset_region(struct _RegionHandle *);
extern struct _RegionHandle *_open_dynregion(struct _DynRegionFrame *f,
                                             struct _DynRegionHandle *h);
extern void   _pop_dynregion();

/* Exceptions */
struct _handler_cons {
  struct _RuntimeStack s;
  jmp_buf handler;
};
extern void _push_handler(struct _handler_cons *);
extern void _push_region(struct _RegionHandle *);
extern void _npop_handler(int);
extern void _pop_handler();
extern void _pop_region();

#ifndef _throw
extern int _throw_null_fn(const char *filename, unsigned lineno);
extern int _throw_arraybounds_fn(const char *filename, unsigned lineno);
extern int _throw_badalloc_fn(const char *filename, unsigned lineno);
extern int _throw_match_fn(const char *filename, unsigned lineno);
extern int _throw_fn(void* e, const char *filename, unsigned lineno);
#define _throw_null() (_throw_null_fn(__FILE__,__LINE__))
#define _throw_arraybounds() (_throw_arraybounds_fn(__FILE__,__LINE__))
#define _throw_badalloc() (_throw_badalloc_fn(__FILE__,__LINE__))
#define _throw_match() (_throw_match_fn(__FILE__,__LINE__))
#define _throw(e) (_throw_fn((e),__FILE__,__LINE__))
#endif

extern struct _xtunion_struct *_exn_thrown;

/* Built-in Exceptions */
struct Cyc_Null_Exception_exn_struct { char *tag; };
struct Cyc_Array_bounds_exn_struct { char *tag; };
struct Cyc_Match_Exception_exn_struct { char *tag; };
struct Cyc_Bad_alloc_exn_struct { char *tag; };
extern char Cyc_Null_Exception[];
extern char Cyc_Array_bounds[];
extern char Cyc_Match_Exception[];
extern char Cyc_Bad_alloc[];

/* Built-in Run-time Checks and company */
#ifdef __APPLE__
#define _INLINE_FUNCTIONS
#endif

#ifdef CYC_ANSI_OUTPUT
#define _INLINE  
#define _INLINE_FUNCTIONS
#else
#define _INLINE inline
#endif

#ifdef VC_C
#define _CYC_U_LONG_LONG_T __int64
#else
#ifdef GCC_C
#define _CYC_U_LONG_LONG_T unsigned long long
#else
#define _CYC_U_LONG_LONG_T unsigned long long
#endif
#endif

#ifdef NO_CYC_NULL_CHECKS
#define _check_null(ptr) (ptr)
#else
#ifdef _INLINE_FUNCTIONS
static _INLINE void *
_check_null_fn(const void *ptr, const char *filename, unsigned lineno) {
  void*_check_null_temp = (void*)(ptr);
  if (!_check_null_temp) _throw_null_fn(filename,lineno);
  return _check_null_temp;
}
#define _check_null(p) (_check_null_fn((p),__FILE__,__LINE__))
#else
#define _check_null(ptr) \
  ({ void*_check_null_temp = (void*)(ptr); \
     if (!_check_null_temp) _throw_null(); \
     _check_null_temp; })
#endif
#endif

#ifdef NO_CYC_BOUNDS_CHECKS
#define _check_known_subscript_null(ptr,bound,elt_sz,index) ({ \
  ((char *)ptr) + (elt_sz)*(index); })
#else
#ifdef _INLINE_FUNCTIONS
static _INLINE char *
_check_known_subscript_null_fn(void *ptr, unsigned bound, unsigned elt_sz, unsigned index, const char *filename, unsigned lineno) {
  void*_cks_ptr = (void*)(ptr);
  unsigned _cks_bound = (bound);
  unsigned _cks_elt_sz = (elt_sz);
  unsigned _cks_index = (index);
  if (!_cks_ptr) _throw_null_fn(filename,lineno);
  if (_cks_index >= _cks_bound) _throw_arraybounds_fn(filename,lineno);
  return ((char *)_cks_ptr) + _cks_elt_sz*_cks_index;
}
#define _check_known_subscript_null(p,b,e) (_check_known_subscript_null_fn(p,b,e,__FILE__,__LINE__))
#else
#define _check_known_subscript_null(ptr,bound,elt_sz,index) ({ \
  void*_cks_ptr = (void*)(ptr); \
  unsigned _cks_bound = (bound); \
  unsigned _cks_elt_sz = (elt_sz); \
  unsigned _cks_index = (index); \
  if (!_cks_ptr) _throw_null(); \
  if (_cks_index >= _cks_bound) _throw_arraybounds(); \
  ((char *)_cks_ptr) + _cks_elt_sz*_cks_index; })
#endif
#endif

#ifdef NO_CYC_BOUNDS_CHECKS
#define _check_known_subscript_notnull(bound,index) (index)
#else
#ifdef _INLINE_FUNCTIONS
static _INLINE unsigned
_check_known_subscript_notnull_fn(unsigned bound,unsigned index,const char *filename,unsigned lineno) { 
  unsigned _cksnn_bound = (bound); 
  unsigned _cksnn_index = (index); 
  if (_cksnn_index >= _cksnn_bound) _throw_arraybounds_fn(filename,lineno); 
  return _cksnn_index;
}
#define _check_known_subscript_notnull(b,i) (_check_known_subscript_notnull_fn(b,i,__FILE__,__LINE__))
#else
#define _check_known_subscript_notnull(bound,index) ({ \
  unsigned _cksnn_bound = (bound); \
  unsigned _cksnn_index = (index); \
  if (_cksnn_index >= _cksnn_bound) _throw_arraybounds(); \
  _cksnn_index; })
#endif
#endif

/* Add i to zero-terminated pointer x.  Checks for x being null and
   ensures that x[0..i-1] are not 0. */
#ifdef NO_CYC_BOUNDS_CHECK
#define _zero_arr_plus_char_fn(orig_x,orig_sz,orig_i,f,l) ((orig_x)+(orig_i))
#define _zero_arr_plus_short_fn(orig_x,orig_sz,orig_i,f,l) ((orig_x)+(orig_i))
#define _zero_arr_plus_int_fn(orig_x,orig_sz,orig_i,f,l) ((orig_x)+(orig_i))
#define _zero_arr_plus_float_fn(orig_x,orig_sz,orig_i,f,l) ((orig_x)+(orig_i))
#define _zero_arr_plus_double_fn(orig_x,orig_sz,orig_i,f,l) ((orig_x)+(orig_i))
#define _zero_arr_plus_longdouble_fn(orig_x,orig_sz,orig_i,f,l) ((orig_x)+(orig_i))
#define _zero_arr_plus_voidstar_fn(orig_x,orig_sz,orig_i,f,l) ((orig_x)+(orig_i))
#else
static _INLINE char *
_zero_arr_plus_char_fn(char *orig_x, unsigned int orig_sz, int orig_i,const char *filename, unsigned lineno) {
  unsigned int _czs_temp;
  if ((orig_x) == 0) _throw_null_fn(filename,lineno);
  if (orig_i < 0 || orig_sz == 0) _throw_arraybounds_fn(filename,lineno);
  for (_czs_temp=orig_sz-1; _czs_temp < orig_i; _czs_temp++)
    if (orig_x[_czs_temp] == 0) _throw_arraybounds_fn(filename,lineno);
  return orig_x + orig_i;
}
static _INLINE short *
_zero_arr_plus_short_fn(short *orig_x, unsigned int orig_sz, int orig_i,const char *filename, unsigned lineno) {
  unsigned int _czs_temp;
  if ((orig_x) == 0) _throw_null_fn(filename,lineno);
  if (orig_i < 0 || orig_sz == 0) _throw_arraybounds_fn(filename,lineno);
  for (_czs_temp=orig_sz-1; _czs_temp < orig_i; _czs_temp++)
    if (orig_x[_czs_temp] == 0) _throw_arraybounds_fn(filename,lineno);
  return orig_x + orig_i;
}
static _INLINE int *
_zero_arr_plus_int_fn(int *orig_x, unsigned int orig_sz, int orig_i, const char *filename, unsigned lineno) {
  unsigned int _czs_temp;
  if ((orig_x) == 0) _throw_null_fn(filename,lineno);
  if (orig_i < 0 || orig_sz == 0) _throw_arraybounds_fn(filename,lineno);
  for (_czs_temp=orig_sz-1; _czs_temp < orig_i; _czs_temp++)
    if (orig_x[_czs_temp] == 0) _throw_arraybounds_fn(filename,lineno);
  return orig_x + orig_i;
}
static _INLINE float *
_zero_arr_plus_float_fn(float *orig_x, unsigned int orig_sz, int orig_i,const char *filename, unsigned lineno) {
  unsigned int _czs_temp;
  if ((orig_x) == 0) _throw_null_fn(filename,lineno);
  if (orig_i < 0 || orig_sz == 0) _throw_arraybounds_fn(filename,lineno);
  for (_czs_temp=orig_sz-1; _czs_temp < orig_i; _czs_temp++)
    if (orig_x[_czs_temp] == 0) _throw_arraybounds_fn(filename,lineno);
  return orig_x + orig_i;
}
static _INLINE double *
_zero_arr_plus_double_fn(double *orig_x, unsigned int orig_sz, int orig_i,const char *filename, unsigned lineno) {
  unsigned int _czs_temp;
  if ((orig_x) == 0) _throw_null_fn(filename,lineno);
  if (orig_i < 0 || orig_sz == 0) _throw_arraybounds_fn(filename,lineno);
  for (_czs_temp=orig_sz-1; _czs_temp < orig_i; _czs_temp++)
    if (orig_x[_czs_temp] == 0) _throw_arraybounds_fn(filename,lineno);
  return orig_x + orig_i;
}
static _INLINE long double *
_zero_arr_plus_longdouble_fn(long double *orig_x, unsigned int orig_sz, int orig_i, const char *filename, unsigned lineno) {
  unsigned int _czs_temp;
  if ((orig_x) == 0) _throw_null_fn(filename,lineno);
  if (orig_i < 0 || orig_sz == 0) _throw_arraybounds_fn(filename,lineno);
  for (_czs_temp=orig_sz-1; _czs_temp < orig_i; _czs_temp++)
    if (orig_x[_czs_temp] == 0) _throw_arraybounds_fn(filename,lineno);
  return orig_x + orig_i;
}
static _INLINE void *
_zero_arr_plus_voidstar_fn(void **orig_x, unsigned int orig_sz, int orig_i,const char *filename,unsigned lineno) {
  unsigned int _czs_temp;
  if ((orig_x) == 0) _throw_null_fn(filename,lineno);
  if (orig_i < 0 || orig_sz == 0) _throw_arraybounds_fn(filename,lineno);
  for (_czs_temp=orig_sz-1; _czs_temp < orig_i; _czs_temp++)
    if (orig_x[_czs_temp] == 0) _throw_arraybounds_fn(filename,lineno);
  return orig_x + orig_i;
}
#endif

#define _zero_arr_plus_char(x,s,i) \
  (_zero_arr_plus_char_fn(x,s,i,__FILE__,__LINE__))
#define _zero_arr_plus_short(x,s,i) \
  (_zero_arr_plus_short_fn(x,s,i,__FILE__,__LINE__))
#define _zero_arr_plus_int(x,s,i) \
  (_zero_arr_plus_int_fn(x,s,i,__FILE__,__LINE__))
#define _zero_arr_plus_float(x,s,i) \
  (_zero_arr_plus_float_fn(x,s,i,__FILE__,__LINE__))
#define _zero_arr_plus_double(x,s,i) \
  (_zero_arr_plus_double_fn(x,s,i,__FILE__,__LINE__))
#define _zero_arr_plus_longdouble(x,s,i) \
  (_zero_arr_plus_longdouble_fn(x,s,i,__FILE__,__LINE__))
#define _zero_arr_plus_voidstar(x,s,i) \
  (_zero_arr_plus_voidstar_fn(x,s,i,__FILE__,__LINE__))


/* Calculates the number of elements in a zero-terminated, thin array.
   If non-null, the array is guaranteed to have orig_offset elements. */
static _INLINE int
_get_zero_arr_size_char(const char *orig_x, unsigned int orig_offset) {
  const char *_gres_x = orig_x;
  unsigned int _gres = 0;
  if (_gres_x != 0) {
     _gres = orig_offset;
     _gres_x += orig_offset - 1;
     while (*_gres_x != 0) { _gres_x++; _gres++; }
  }
  return _gres; 
}
static _INLINE int
_get_zero_arr_size_short(const short *orig_x, unsigned int orig_offset) {
  const short *_gres_x = orig_x;
  unsigned int _gres = 0;
  if (_gres_x != 0) {
     _gres = orig_offset;
     _gres_x += orig_offset - 1;
     while (*_gres_x != 0) { _gres_x++; _gres++; }
  }
  return _gres; 
}
static _INLINE int
_get_zero_arr_size_int(const int *orig_x, unsigned int orig_offset) {
  const int *_gres_x = orig_x;
  unsigned int _gres = 0;
  if (_gres_x != 0) {
     _gres = orig_offset;
     _gres_x += orig_offset - 1;
     while (*_gres_x != 0) { _gres_x++; _gres++; }
  }
  return _gres; 
}
static _INLINE int
_get_zero_arr_size_float(const float *orig_x, unsigned int orig_offset) {
  const float *_gres_x = orig_x;
  unsigned int _gres = 0;
  if (_gres_x != 0) {
     _gres = orig_offset;
     _gres_x += orig_offset - 1;
     while (*_gres_x != 0) { _gres_x++; _gres++; }
  }
  return _gres; 
}
static _INLINE int
_get_zero_arr_size_double(const double *orig_x, unsigned int orig_offset) {
  const double *_gres_x = orig_x;
  unsigned int _gres = 0;
  if (_gres_x != 0) {
     _gres = orig_offset;
     _gres_x += orig_offset - 1;
     while (*_gres_x != 0) { _gres_x++; _gres++; }
  }
  return _gres; 
}
static _INLINE int
_get_zero_arr_size_longdouble(const long double *orig_x, unsigned int orig_offset) {
  const long double *_gres_x = orig_x;
  unsigned int _gres = 0;
  if (_gres_x != 0) {
     _gres = orig_offset;
     _gres_x += orig_offset - 1;
     while (*_gres_x != 0) { _gres_x++; _gres++; }
  }
  return _gres; 
}
static _INLINE int
_get_zero_arr_size_voidstar(const void **orig_x, unsigned int orig_offset) {
  const void **_gres_x = orig_x;
  unsigned int _gres = 0;
  if (_gres_x != 0) {
     _gres = orig_offset;
     _gres_x += orig_offset - 1;
     while (*_gres_x != 0) { _gres_x++; _gres++; }
  }
  return _gres; 
}


/* Does in-place addition of a zero-terminated pointer (x += e and ++x).  
   Note that this expands to call _zero_arr_plus_<type>_fn. */
static _INLINE char *
_zero_arr_inplace_plus_char_fn(char **x, int orig_i,const char *filename,unsigned lineno) {
  *x = _zero_arr_plus_char_fn(*x,1,orig_i,filename,lineno);
  return *x;
}
#define _zero_arr_inplace_plus_char(x,i) \
  _zero_arr_inplace_plus_char_fn((char **)(x),i,__FILE__,__LINE__)
static _INLINE short *
_zero_arr_inplace_plus_short_fn(short **x, int orig_i,const char *filename,unsigned lineno) {
  *x = _zero_arr_plus_short_fn(*x,1,orig_i,filename,lineno);
  return *x;
}
#define _zero_arr_inplace_plus_short(x,i) \
  _zero_arr_inplace_plus_short_fn((short **)(x),i,__FILE__,__LINE__)
static _INLINE int *
_zero_arr_inplace_plus_int(int **x, int orig_i,const char *filename,unsigned lineno) {
  *x = _zero_arr_plus_int_fn(*x,1,orig_i,filename,lineno);
  return *x;
}
#define _zero_arr_inplace_plus_int(x,i) \
  _zero_arr_inplace_plus_int_fn((int **)(x),i,__FILE__,__LINE__)
static _INLINE float *
_zero_arr_inplace_plus_float_fn(float **x, int orig_i,const char *filename,unsigned lineno) {
  *x = _zero_arr_plus_float_fn(*x,1,orig_i,filename,lineno);
  return *x;
}
#define _zero_arr_inplace_plus_float(x,i) \
  _zero_arr_inplace_plus_float_fn((float **)(x),i,__FILE__,__LINE__)
static _INLINE double *
_zero_arr_inplace_plus_double_fn(double **x, int orig_i,const char *filename,unsigned lineno) {
  *x = _zero_arr_plus_double_fn(*x,1,orig_i,filename,lineno);
  return *x;
}
#define _zero_arr_inplace_plus_double(x,i) \
  _zero_arr_inplace_plus_double_fn((double **)(x),i,__FILE__,__LINE__)
static _INLINE long double *
_zero_arr_inplace_plus_longdouble_fn(long double **x, int orig_i,const char *filename,unsigned lineno) {
  *x = _zero_arr_plus_longdouble_fn(*x,1,orig_i,filename,lineno);
  return *x;
}
#define _zero_arr_inplace_plus_longdouble(x,i) \
  _zero_arr_inplace_plus_longdouble_fn((long double **)(x),i,__FILE__,__LINE__)
static _INLINE void *
_zero_arr_inplace_plus_voidstar_fn(void ***x, int orig_i,const char *filename,unsigned lineno) {
  *x = _zero_arr_plus_voidstar_fn(*x,1,orig_i,filename,lineno);
  return *x;
}
#define _zero_arr_inplace_plus_voidstar(x,i) \
  _zero_arr_inplace_plus_voidstar_fn((void ***)(x),i,__FILE__,__LINE__)

/* Does in-place increment of a zero-terminated pointer (e.g., x++). */
static _INLINE char *
_zero_arr_inplace_plus_post_char_fn(char **x, int orig_i,const char *filename,unsigned lineno){
  char * _zap_res = *x;
  *x = _zero_arr_plus_char_fn(_zap_res,1,orig_i,filename,lineno);
  return _zap_res;
}
#define _zero_arr_inplace_plus_post_char(x,i) \
  _zero_arr_inplace_plus_post_char_fn((char **)(x),(i),__FILE__,__LINE__)
static _INLINE short *
_zero_arr_inplace_plus_post_short_fn(short **x, int orig_i,const char *filename,unsigned lineno){
  short * _zap_res = *x;
  *x = _zero_arr_plus_short_fn(_zap_res,1,orig_i,filename,lineno);
  return _zap_res;
}
#define _zero_arr_inplace_plus_post_short(x,i) \
  _zero_arr_inplace_plus_post_short_fn((short **)(x),(i),__FILE__,__LINE__)
static _INLINE int *
_zero_arr_inplace_plus_post_int_fn(int **x, int orig_i,const char *filename, unsigned lineno){
  int * _zap_res = *x;
  *x = _zero_arr_plus_int_fn(_zap_res,1,orig_i,filename,lineno);
  return _zap_res;
}
#define _zero_arr_inplace_plus_post_int(x,i) \
  _zero_arr_inplace_plus_post_int_fn((int **)(x),(i),__FILE__,__LINE__)
static _INLINE float *
_zero_arr_inplace_plus_post_float_fn(float **x, int orig_i,const char *filename, unsigned lineno){
  float * _zap_res = *x;
  *x = _zero_arr_plus_float_fn(_zap_res,1,orig_i,filename,lineno);
  return _zap_res;
}
#define _zero_arr_inplace_plus_post_float(x,i) \
  _zero_arr_inplace_plus_post_float_fn((float **)(x),(i),__FILE__,__LINE__)
static _INLINE double *
_zero_arr_inplace_plus_post_double_fn(double **x, int orig_i,const char *filename,unsigned lineno){
  double * _zap_res = *x;
  *x = _zero_arr_plus_double_fn(_zap_res,1,orig_i,filename,lineno);
  return _zap_res;
}
#define _zero_arr_inplace_plus_post_double(x,i) \
  _zero_arr_inplace_plus_post_double_fn((double **)(x),(i),__FILE__,__LINE__)
static _INLINE long double *
_zero_arr_inplace_plus_post_longdouble_fn(long double **x, int orig_i,const char *filename,unsigned lineno){
  long double * _zap_res = *x;
  *x = _zero_arr_plus_longdouble_fn(_zap_res,1,orig_i,filename,lineno);
  return _zap_res;
}
#define _zero_arr_inplace_plus_post_longdouble(x,i) \
  _zero_arr_inplace_plus_post_longdouble_fn((long double **)(x),(i),__FILE__,__LINE__)
static _INLINE void **
_zero_arr_inplace_plus_post_voidstar_fn(void ***x, int orig_i,const char *filename,unsigned lineno){
  void ** _zap_res = *x;
  *x = _zero_arr_plus_voidstar_fn(_zap_res,1,orig_i,filename,lineno);
  return _zap_res;
}
#define _zero_arr_inplace_plus_post_voidstar(x,i) \
  _zero_arr_inplace_plus_post_voidstar_fn((void***)(x),(i),__FILE__,__LINE__)

/* functions for dealing with dynamically sized pointers */
#ifdef NO_CYC_BOUNDS_CHECKS
#ifdef _INLINE_FUNCTIONS
static _INLINE unsigned char *
_check_dyneither_subscript(struct _dyneither_ptr arr,unsigned elt_sz,unsigned index) {
  struct _dyneither_ptr _cus_arr = (arr);
  unsigned _cus_elt_sz = (elt_sz);
  unsigned _cus_index = (index);
  unsigned char *_cus_ans = _cus_arr.curr + _cus_elt_sz * _cus_index;
  return _cus_ans;
}
#else
#define _check_dyneither_subscript(arr,elt_sz,index) ({ \
  struct _dyneither_ptr _cus_arr = (arr); \
  unsigned _cus_elt_sz = (elt_sz); \
  unsigned _cus_index = (index); \
  unsigned char *_cus_ans = _cus_arr.curr + _cus_elt_sz * _cus_index; \
  _cus_ans; })
#endif
#else
#ifdef _INLINE_FUNCTIONS
static _INLINE unsigned char *
_check_dyneither_subscript_fn(struct _dyneither_ptr arr,unsigned elt_sz,unsigned index,const char *filename, unsigned lineno) {
  struct _dyneither_ptr _cus_arr = (arr);
  unsigned _cus_elt_sz = (elt_sz);
  unsigned _cus_index = (index);
  unsigned char *_cus_ans = _cus_arr.curr + _cus_elt_sz * _cus_index;
  /* JGM: not needed! if (!_cus_arr.base) _throw_null(); */ 
  if (_cus_ans < _cus_arr.base || _cus_ans >= _cus_arr.last_plus_one)
    _throw_arraybounds_fn(filename,lineno);
  return _cus_ans;
}
#define _check_dyneither_subscript(a,s,i) \
  _check_dyneither_subscript_fn(a,s,i,__FILE__,__LINE__)
#else
#define _check_dyneither_subscript(arr,elt_sz,index) ({ \
  struct _dyneither_ptr _cus_arr = (arr); \
  unsigned _cus_elt_sz = (elt_sz); \
  unsigned _cus_index = (index); \
  unsigned char *_cus_ans = _cus_arr.curr + _cus_elt_sz * _cus_index; \
  /* JGM: not needed! if (!_cus_arr.base) _throw_null();*/ \
  if (_cus_ans < _cus_arr.base || _cus_ans >= _cus_arr.last_plus_one) \
    _throw_arraybounds(); \
  _cus_ans; })
#endif
#endif

#ifdef _INLINE_FUNCTIONS
static _INLINE struct _dyneither_ptr
_tag_dyneither(const void *tcurr,unsigned elt_sz,unsigned num_elts) {
  struct _dyneither_ptr _tag_arr_ans;
  _tag_arr_ans.base = _tag_arr_ans.curr = (void*)(tcurr);
  _tag_arr_ans.last_plus_one = _tag_arr_ans.base + (elt_sz) * (num_elts);
  return _tag_arr_ans;
}
#else
#define _tag_dyneither(tcurr,elt_sz,num_elts) ({ \
  struct _dyneither_ptr _tag_arr_ans; \
  _tag_arr_ans.base = _tag_arr_ans.curr = (void*)(tcurr); \
  _tag_arr_ans.last_plus_one = _tag_arr_ans.base + (elt_sz) * (num_elts); \
  _tag_arr_ans; })
#endif

#ifdef _INLINE_FUNCTIONS
static _INLINE struct _dyneither_ptr *
_init_dyneither_ptr(struct _dyneither_ptr *arr_ptr,
                    void *arr, unsigned elt_sz, unsigned num_elts) {
  struct _dyneither_ptr *_itarr_ptr = (arr_ptr);
  void* _itarr = (arr);
  _itarr_ptr->base = _itarr_ptr->curr = _itarr;
  _itarr_ptr->last_plus_one = ((unsigned char *)_itarr) + (elt_sz) * (num_elts);
  return _itarr_ptr;
}
#else
#define _init_dyneither_ptr(arr_ptr,arr,elt_sz,num_elts) ({ \
  struct _dyneither_ptr *_itarr_ptr = (arr_ptr); \
  void* _itarr = (arr); \
  _itarr_ptr->base = _itarr_ptr->curr = _itarr; \
  _itarr_ptr->last_plus_one = ((char *)_itarr) + (elt_sz) * (num_elts); \
  _itarr_ptr; })
#endif

#ifdef NO_CYC_BOUNDS_CHECKS
#define _untag_dyneither_ptr(arr,elt_sz,num_elts) ((arr).curr)
#else
#ifdef _INLINE_FUNCTIONS
static _INLINE unsigned char *
_untag_dyneither_ptr_fn(struct _dyneither_ptr arr, 
                        unsigned elt_sz,unsigned num_elts,
                        const char *filename, unsigned lineno) {
  struct _dyneither_ptr _arr = (arr);
  unsigned char *_curr = _arr.curr;
  if (_curr < _arr.base || _curr + (elt_sz) * (num_elts) > _arr.last_plus_one)
    _throw_arraybounds_fn(filename,lineno);
  return _curr;
}
#define _untag_dyneither_ptr(a,s,e) \
  _untag_dyneither_ptr_fn(a,s,e,__FILE__,__LINE__)
#else
#define _untag_dyneither_ptr(arr,elt_sz,num_elts) ({ \
  struct _dyneither_ptr _arr = (arr); \
  unsigned char *_curr = _arr.curr; \
  if (_curr < _arr.base || _curr + (elt_sz) * (num_elts) > _arr.last_plus_one)\
    _throw_arraybounds(); \
  _curr; })
#endif
#endif

#ifdef _INLINE_FUNCTIONS
static _INLINE unsigned
_get_dyneither_size(struct _dyneither_ptr arr,unsigned elt_sz) {
  struct _dyneither_ptr _get_arr_size_temp = (arr);
  unsigned char *_get_arr_size_curr=_get_arr_size_temp.curr;
  unsigned char *_get_arr_size_last=_get_arr_size_temp.last_plus_one;
  return (_get_arr_size_curr < _get_arr_size_temp.base ||
          _get_arr_size_curr >= _get_arr_size_last) ? 0 :
    ((_get_arr_size_last - _get_arr_size_curr) / (elt_sz));
}
#else
#define _get_dyneither_size(arr,elt_sz) \
  ({struct _dyneither_ptr _get_arr_size_temp = (arr); \
    unsigned char *_get_arr_size_curr=_get_arr_size_temp.curr; \
    unsigned char *_get_arr_size_last=_get_arr_size_temp.last_plus_one; \
    (_get_arr_size_curr < _get_arr_size_temp.base || \
     _get_arr_size_curr >= _get_arr_size_last) ? 0 : \
    ((_get_arr_size_last - _get_arr_size_curr) / (elt_sz));})
#endif

#ifdef _INLINE_FUNCTIONS
static _INLINE struct _dyneither_ptr
_dyneither_ptr_plus(struct _dyneither_ptr arr,unsigned elt_sz,int change) {
  struct _dyneither_ptr _ans = (arr);
  _ans.curr += ((int)(elt_sz))*(change);
  return _ans;
}
#else
#define _dyneither_ptr_plus(arr,elt_sz,change) ({ \
  struct _dyneither_ptr _ans = (arr); \
  _ans.curr += ((int)(elt_sz))*(change); \
  _ans; })
#endif

#ifdef _INLINE_FUNCTIONS
static _INLINE struct _dyneither_ptr
_dyneither_ptr_inplace_plus(struct _dyneither_ptr *arr_ptr,unsigned elt_sz,
                            int change) {
  struct _dyneither_ptr * _arr_ptr = (arr_ptr);
  _arr_ptr->curr += ((int)(elt_sz))*(change);
  return *_arr_ptr;
}
#else
#define _dyneither_ptr_inplace_plus(arr_ptr,elt_sz,change) ({ \
  struct _dyneither_ptr * _arr_ptr = (arr_ptr); \
  _arr_ptr->curr += ((int)(elt_sz))*(change); \
  *_arr_ptr; })
#endif

#ifdef _INLINE_FUNCTIONS
static _INLINE struct _dyneither_ptr
_dyneither_ptr_inplace_plus_post(struct _dyneither_ptr *arr_ptr,unsigned elt_sz,int change) {
  struct _dyneither_ptr * _arr_ptr = (arr_ptr);
  struct _dyneither_ptr _ans = *_arr_ptr;
  _arr_ptr->curr += ((int)(elt_sz))*(change);
  return _ans;
}
#else
#define _dyneither_ptr_inplace_plus_post(arr_ptr,elt_sz,change) ({ \
  struct _dyneither_ptr * _arr_ptr = (arr_ptr); \
  struct _dyneither_ptr _ans = *_arr_ptr; \
  _arr_ptr->curr += ((int)(elt_sz))*(change); \
  _ans; })
#endif

/* Decrease the upper bound on a fat pointer by numelts where sz is
   the size of the pointer's type.  Note that this can't be a macro
   if we're to get initializers right. */
static struct 
_dyneither_ptr _dyneither_ptr_decrease_size(struct _dyneither_ptr x,
                                            unsigned int sz,
                                            unsigned int numelts) {
  x.last_plus_one -= sz * numelts; 
  return x; 
}

/* Allocation */

extern void* GC_malloc(int);
extern void* GC_malloc_atomic(int);
extern void* GC_calloc(unsigned,unsigned);
extern void* GC_calloc_atomic(unsigned,unsigned);

/* FIX?  Not sure if we want to pass filename and lineno in here... */
static _INLINE void* _cycalloc(int n) {
  void * ans = (void *)GC_malloc(n);
  if(!ans)
    _throw_badalloc();
  return ans;
}
static _INLINE void* _cycalloc_atomic(int n) {
  void * ans = (void *)GC_malloc_atomic(n);
  if(!ans)
    _throw_badalloc();
  return ans;
}
static _INLINE void* _cyccalloc(unsigned n, unsigned s) {
  void* ans = (void*)GC_calloc(n,s);
  if (!ans)
    _throw_badalloc();
  return ans;
}
static _INLINE void* _cyccalloc_atomic(unsigned n, unsigned s) {
  void* ans = (void*)GC_calloc_atomic(n,s);
  if (!ans)
    _throw_badalloc();
  return ans;
}
#define MAX_MALLOC_SIZE (1 << 28)
static _INLINE unsigned int _check_times(unsigned x, unsigned y) {
  _CYC_U_LONG_LONG_T whole_ans = 
    ((_CYC_U_LONG_LONG_T)x)*((_CYC_U_LONG_LONG_T)y);
  unsigned word_ans = (unsigned)whole_ans;
  if(word_ans < whole_ans || word_ans > MAX_MALLOC_SIZE)
    _throw_badalloc();
  return word_ans;
}

#if defined(CYC_REGION_PROFILE) 
extern void* _profile_GC_malloc(int,const char *file,const char *func,
                                int lineno);
extern void* _profile_GC_malloc_atomic(int,const char *file,
                                       const char *func,int lineno);
extern void* _profile_region_malloc(struct _RegionHandle *, unsigned,
                                    const char *file,
                                    const char *func,
                                    int lineno);
extern void* _profile_region_calloc(struct _RegionHandle *, unsigned,
                                    unsigned,
                                    const char *file,
                                    const char *func,
                                    int lineno);
extern struct _RegionHandle _profile_new_region(const char *rgn_name,
						const char *file,
						const char *func,
                                                int lineno);
extern void _profile_free_region(struct _RegionHandle *,
				 const char *file,
                                 const char *func,
                                 int lineno);
#  if !defined(RUNTIME_CYC)
#define _new_region(n) _profile_new_region(n,__FILE__,__FUNCTION__,__LINE__)
#define _free_region(r) _profile_free_region(r,__FILE__,__FUNCTION__,__LINE__)
#define _region_malloc(rh,n) _profile_region_malloc(rh,n,__FILE__,__FUNCTION__,__LINE__)
#define _region_calloc(rh,n,t) _profile_region_calloc(rh,n,t,__FILE__,__FUNCTION__,__LINE__)
#  endif
#define _cycalloc(n) _profile_GC_malloc(n,__FILE__,__FUNCTION__,__LINE__)
#define _cycalloc_atomic(n) _profile_GC_malloc_atomic(n,__FILE__,__FUNCTION__,__LINE__)
#endif
#endif

/* the next two routines swap [x] and [y]; not thread safe! */
static _INLINE void _swap_word(void *x, void *y) {
  unsigned long *lx = (unsigned long *)x, *ly = (unsigned long *)y, tmp;
  tmp = *lx;
  *lx = *ly;
  *ly = tmp;
}
static _INLINE void _swap_dyneither(struct _dyneither_ptr *x, 
				   struct _dyneither_ptr *y) {
  struct _dyneither_ptr tmp = *x;
  *x = *y;
  *y = tmp;
}

# 35 "include/core.h"
 typedef char*Cyc_Cstring;
typedef char*Cyc_CstringNN;
typedef struct _dyneither_ptr Cyc_string_t;
# 40
typedef struct _dyneither_ptr Cyc_mstring_t;
# 43
typedef struct _dyneither_ptr*Cyc_stringptr_t;
# 47
typedef struct _dyneither_ptr*Cyc_mstringptr_t;
# 50
typedef char*Cyc_Cbuffer_t;
# 52
typedef char*Cyc_CbufferNN_t;
# 54
typedef struct _dyneither_ptr Cyc_buffer_t;
# 56
typedef struct _dyneither_ptr Cyc_mbuffer_t;
# 59
typedef int Cyc_bool;
# 26 "include/cycboot.h"
typedef unsigned long Cyc_size_t;
# 33
typedef unsigned short Cyc_mode_t;
# 38
int Cyc_open(const char*,int,struct _dyneither_ptr);struct Cyc___cycFILE;
# 49
typedef struct Cyc___cycFILE Cyc_FILE;struct Cyc_String_pa_PrintArg_struct{int tag;struct _dyneither_ptr f1;};struct Cyc_Int_pa_PrintArg_struct{int tag;unsigned long f1;};struct Cyc_Double_pa_PrintArg_struct{int tag;double f1;};struct Cyc_LongDouble_pa_PrintArg_struct{int tag;long double f1;};struct Cyc_ShortPtr_pa_PrintArg_struct{int tag;short*f1;};struct Cyc_IntPtr_pa_PrintArg_struct{int tag;unsigned long*f1;};
# 68
typedef void*Cyc_parg_t;
# 79
int Cyc_fclose(struct Cyc___cycFILE*);
# 84
int Cyc_feof(struct Cyc___cycFILE*);
# 88
int Cyc_fflush(struct Cyc___cycFILE*);
# 90
int Cyc_fgetc(struct Cyc___cycFILE*);
# 98
struct Cyc___cycFILE*Cyc_fopen(const char*,const char*);
# 104
int Cyc_fputc(int,struct Cyc___cycFILE*);
# 106
int Cyc_fputs(const char*,struct Cyc___cycFILE*);
# 108
unsigned long Cyc_fread(struct _dyneither_ptr,unsigned long,unsigned long,struct Cyc___cycFILE*);struct Cyc_ShortPtr_sa_ScanfArg_struct{int tag;short*f1;};struct Cyc_UShortPtr_sa_ScanfArg_struct{int tag;unsigned short*f1;};struct Cyc_IntPtr_sa_ScanfArg_struct{int tag;int*f1;};struct Cyc_UIntPtr_sa_ScanfArg_struct{int tag;unsigned int*f1;};struct Cyc_StringPtr_sa_ScanfArg_struct{int tag;struct _dyneither_ptr f1;};struct Cyc_DoublePtr_sa_ScanfArg_struct{int tag;double*f1;};struct Cyc_FloatPtr_sa_ScanfArg_struct{int tag;float*f1;};struct Cyc_CharPtr_sa_ScanfArg_struct{int tag;struct _dyneither_ptr f1;};
# 127
typedef void*Cyc_sarg_t;
# 140
unsigned long Cyc_fwrite(struct _dyneither_ptr,unsigned long,unsigned long,struct Cyc___cycFILE*);
# 142
int Cyc_getc(struct Cyc___cycFILE*);
# 161
int Cyc_putc(int,struct Cyc___cycFILE*);
# 222
int Cyc_ungetc(int,struct Cyc___cycFILE*);
# 252
int Cyc_getw(struct Cyc___cycFILE*);
# 255
int Cyc_putw(int,struct Cyc___cycFILE*);extern char Cyc_FileCloseError[15];struct Cyc_FileCloseError_exn_struct{char*tag;};extern char Cyc_FileOpenError[14];struct Cyc_FileOpenError_exn_struct{char*tag;struct _dyneither_ptr f1;};
# 271
struct Cyc___cycFILE*Cyc_file_open(struct _dyneither_ptr,struct _dyneither_ptr);
void Cyc_file_close(struct Cyc___cycFILE*);
# 326
struct _dyneither_ptr Cyc_getcwd(struct _dyneither_ptr buf,unsigned long size);
# 79 "include/core.h"
typedef unsigned int Cyc_Core_sizeof_t;struct Cyc_Core_Opt{void*v;};
# 83
typedef struct Cyc_Core_Opt*Cyc_Core_opt_t;extern char Cyc_Core_Invalid_argument[17];struct Cyc_Core_Invalid_argument_exn_struct{char*tag;struct _dyneither_ptr f1;};extern char Cyc_Core_Failure[8];struct Cyc_Core_Failure_exn_struct{char*tag;struct _dyneither_ptr f1;};extern char Cyc_Core_Impossible[11];struct Cyc_Core_Impossible_exn_struct{char*tag;struct _dyneither_ptr f1;};extern char Cyc_Core_Not_found[10];struct Cyc_Core_Not_found_exn_struct{char*tag;};extern char Cyc_Core_Unreachable[12];struct Cyc_Core_Unreachable_exn_struct{char*tag;struct _dyneither_ptr f1;};
# 152
extern struct _RegionHandle*Cyc_Core_unique_region;struct Cyc_Core_DynamicRegion;
# 187
typedef struct Cyc_Core_DynamicRegion*Cyc_Core_region_key_t;
# 193
typedef struct Cyc_Core_DynamicRegion*Cyc_Core_uregion_key_t;
# 198
typedef struct Cyc_Core_DynamicRegion*Cyc_Core_rcregion_key_t;struct Cyc_Core_NewDynamicRegion{struct Cyc_Core_DynamicRegion*key;};
# 271
struct _dyneither_ptr wrap_Cbuffer_as_buffer(char*,unsigned long);
# 280
inline static void* arrcast(struct _dyneither_ptr dyn,unsigned int bd,unsigned int sz){
# 285
if(bd >> 20  || sz >> 12)
return 0;{
unsigned char*ptrbd=dyn.curr + bd * sz;
if(((ptrbd < dyn.curr  || dyn.curr == 0) || dyn.curr < dyn.base) || ptrbd > dyn.last_plus_one)
# 292
return 0;
return dyn.curr;};}
# 5 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/arpa/inet.h"
typedef unsigned short Cyc___uint16_t;
# 9
typedef unsigned int Cyc___uint32_t;
# 13
typedef unsigned short Cyc_uint16_t;
# 17
typedef unsigned int Cyc_uint32_t;
# 21
typedef unsigned short Cyc_u_int16_t;
# 25
typedef unsigned int Cyc_u_int32_t;
# 29
typedef unsigned int Cyc_in_addr_t;
# 33
typedef unsigned short Cyc_in_port_t;struct Cyc_in_addr{unsigned int s_addr;};
# 62
unsigned int Cyc_htonl(unsigned int x);
unsigned short Cyc_htons(unsigned short x);
unsigned int Cyc_ntohl(unsigned int x);
unsigned short Cyc_ntohs(unsigned short x);
# 10 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
unsigned int __stub_htonl(unsigned int x);
unsigned short __stub_htons(unsigned short x);
unsigned int __stub_ntohl(unsigned int x);
unsigned short __stub_ntohs(unsigned short x);
# 15
unsigned int Cyc_htonl(unsigned int x){
return __stub_htonl(x);}
# 18
unsigned short Cyc_htons(unsigned short x){
return __stub_htons(x);}
# 21
unsigned int Cyc_ntohl(unsigned int x){
return __stub_ntohl(x);}
# 24
unsigned short Cyc_ntohs(unsigned short x){
return __stub_ntohs(x);}
# 5 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/dirent.h"
typedef unsigned char Cyc___uint8_t;
# 21
typedef unsigned int Cyc_ino_t;struct Cyc_dirent{unsigned int d_fileno;unsigned short d_reclen;unsigned char d_type;unsigned char d_namlen;char d_name[256];};struct Cyc___cycDIR;
# 37
typedef struct Cyc___cycDIR Cyc_DIR;
# 39
int Cyc_closedir(struct Cyc___cycDIR*);
# 41
struct Cyc___cycDIR*Cyc_opendir(const char*);
# 43
struct Cyc_dirent*Cyc_readdir(struct Cyc___cycDIR*);
# 49
void Cyc_rewinddir(struct Cyc___cycDIR*);
# 51
void Cyc_seekdir(struct Cyc___cycDIR*,long);
# 53
long Cyc_telldir(struct Cyc___cycDIR*);struct  __abstractDIR;
# 39 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
typedef struct  __abstractDIR Cyc_Cdirent___cDIR;struct Cyc___cycDIR{struct  __abstractDIR*dir;};
# 46
int closedir(struct  __abstractDIR*d);
# 48
int Cyc_closedir(struct Cyc___cycDIR*d){
return closedir(d->dir);}
# 53
struct  __abstractDIR*opendir(const char*);static char _tmp1[32]="opendir called with NULL string";
# 55
static struct Cyc_Core_Failure_exn_struct Cyc___opendir_failure={Cyc_Core_Failure,{_tmp1,_tmp1,_tmp1 + 32}};
# 57
struct Cyc___cycDIR*Cyc_opendir(const char*f){
struct  __abstractDIR*_tmp2=opendir(f);
# 60
struct Cyc___cycDIR*_tmp9F;return(unsigned int)_tmp2?(_tmp9F=_cycalloc(sizeof(*_tmp9F)),((_tmp9F->dir=_tmp2,_tmp9F))): 0;}
# 64
struct Cyc_dirent*readdir(struct  __abstractDIR*);
# 66
struct Cyc_dirent*Cyc_readdir(struct Cyc___cycDIR*d){
return readdir(d->dir);}
# 71
void rewinddir(struct  __abstractDIR*d);
# 73
void Cyc_rewinddir(struct Cyc___cycDIR*d){
return rewinddir(d->dir);}
# 78
void seekdir(struct  __abstractDIR*d,long);
# 80
void Cyc_seekdir(struct Cyc___cycDIR*d,long x){
return seekdir(d->dir,x);}
# 85
long telldir(struct  __abstractDIR*d);
# 87
long Cyc_telldir(struct Cyc___cycDIR*d){
return telldir(d->dir);}
# 211 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/errno.h"
int*__CYCLONE_ERRNO();
# 5 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/fcntl.h"
typedef int Cyc___int64_t;
# 21
typedef int Cyc_off_t;
# 25
typedef int Cyc_pid_t;struct Cyc_flock{int l_start;int l_len;int l_pid;short l_type;short l_whence;};struct Cyc_Flock_FcntlArg_struct{int tag;struct Cyc_flock*f1;};struct Cyc_Long_FcntlArg_struct{int tag;long f1;};
# 120
typedef void*Cyc_fcntlarg_t;
# 122
int Cyc_fcntl(int fd,int cmd,struct _dyneither_ptr);
int Cyc_open(const char*,int,struct _dyneither_ptr);
# 97 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
int fcntl(int fd,int cmd);
int fcntl_with_arg(int fd,int cmd,long arg);
int fcntl_with_lock(int fd,int cmd,struct Cyc_flock*lock);
int open_without_mode(const char*,int);
int open_with_mode(const char*,int,unsigned short);static char _tmp5[21]="fcntl: too many args";
# 103
static struct Cyc_Core_Failure_exn_struct Cyc___fcntl_failure={Cyc_Core_Failure,{_tmp5,_tmp5,_tmp5 + 21}};
# 105
int Cyc_fcntl(int fd,int cmd,struct _dyneither_ptr argv){
if(_get_dyneither_size(argv,sizeof(void*))== 0)return fcntl(fd,cmd);else{
if(_get_dyneither_size(argv,sizeof(void*))!= 1)(int)_throw((void*)& Cyc___fcntl_failure);else{
void*_tmp6=((void**)argv.curr)[0];void*_tmp7=_tmp6;long _tmp9;struct Cyc_flock*_tmpB;_LL1: {struct Cyc_Long_FcntlArg_struct*_tmp8=(struct Cyc_Long_FcntlArg_struct*)_tmp7;if(_tmp8->tag != 1)goto _LL3;else{_tmp9=_tmp8->f1;}}_LL2:
 return fcntl_with_arg(fd,cmd,_tmp9);_LL3: {struct Cyc_Flock_FcntlArg_struct*_tmpA=(struct Cyc_Flock_FcntlArg_struct*)_tmp7;if(_tmpA->tag != 0)goto _LL0;else{_tmpB=_tmpA->f1;}}_LL4:
 return fcntl_with_lock(fd,cmd,_tmpB);_LL0:;}}}
# 114
int Cyc_open(const char*s,int i,struct _dyneither_ptr ms){
# 117
if(_get_dyneither_size(ms,sizeof(unsigned short))>= 1)
return open_with_mode(s,i,((unsigned short*)ms.curr)[0]);else{
# 120
return open_without_mode(s,i);}}struct Cyc_servent{char*s_name;char**s_aliases;int s_port;char*s_proto;};struct Cyc_protoent{char*p_name;char**p_aliases;int p_proto;};
# 56 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/netdb.h"
typedef unsigned int Cyc_socklen_t;struct Cyc_hostent{char*h_name;char**h_aliases;int h_addrtype;int h_length;struct Cyc_in_addr**h_addr_list;};
# 17 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/netinet/in.h"
typedef unsigned char Cyc_uint8_t;
# 25
typedef unsigned char Cyc_u_char;
# 29
typedef unsigned short Cyc_u_short;
# 33
typedef unsigned char Cyc_u_int8_t;struct Cyc_sockaddr_in{unsigned char sin_len;unsigned char sin_family;unsigned short sin_port;struct Cyc_in_addr sin_addr;char sin_zero[8];};struct Cyc_in6_addr{union {unsigned char __u6_addr8[16];unsigned short __u6_addr16[8];unsigned int __u6_addr32[4];}__u6_addr;};struct Cyc_sockaddr_in6{unsigned char sin6_len;unsigned char sin6_family;unsigned short sin6_port;unsigned int sin6_flowinfo;struct Cyc_in6_addr sin6_addr;unsigned int sin6_scope_id;};struct Cyc_ipv6_mreq{struct Cyc_in6_addr ipv6mr_multiaddr;unsigned int ipv6mr_interface;};
# 225
typedef unsigned char Cyc_sa_family_t;struct Cyc_pollfd{int fd;short events;short revents;};
# 46 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/poll.h"
typedef unsigned int Cyc_nfds_t;
# 49
int Cyc_poll(struct _dyneither_ptr,unsigned int,int);
# 161 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
int poll(struct Cyc_pollfd*,unsigned int b,int c);static char _tmpD[22]="poll called with NULL";
# 163
static struct Cyc_Core_Failure_exn_struct Cyc___poll_failure_1={Cyc_Core_Failure,{_tmpD,_tmpD,_tmpD + 22}};static char _tmpF[39]="poll called with out-of-bounds pointer";
# 165
static struct Cyc_Core_Failure_exn_struct Cyc___poll_failure_2={Cyc_Core_Failure,{_tmpF,_tmpF,_tmpF + 39}};
# 167
int Cyc_poll(struct _dyneither_ptr a,unsigned int b,int c){
if(!((unsigned int)a.curr))(int)_throw((void*)& Cyc___poll_failure_1);{
int len=(int)_get_dyneither_size(a,sizeof(struct Cyc_pollfd));
if(len < 1)(int)_throw((void*)& Cyc___poll_failure_2);
return poll((struct Cyc_pollfd*)_untag_dyneither_ptr(a,sizeof(struct Cyc_pollfd),0),
b < (unsigned int)len?b:(unsigned int)len,c);};}union Cyc_sigval{int sigval_int;void*sigval_ptr;};struct Cyc___sigset{unsigned int __bits[4];};
# 20 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/signal.h"
typedef struct Cyc___sigset Cyc_sigset_t;
# 26
typedef int Cyc_sig_atomic_t;struct Cyc___siginfo;struct Cyc_sigaction{union {void(*__sa_handler)(int);void(*__sa_sigaction)(int,struct Cyc___siginfo*,void*);}__sigaction_u;int sa_flags;struct Cyc___sigset sa_mask;};struct Cyc_sigaltstack{char*ss_sp;unsigned long ss_size;int ss_flags;};
# 43
typedef struct Cyc_sigaltstack Cyc_stack_t;struct Cyc___mcontext{int mc_onstack;int mc_gs;int mc_fs;int mc_es;int mc_ds;int mc_edi;int mc_esi;int mc_ebp;int mc_isp;int mc_ebx;int mc_edx;int mc_ecx;int mc_eax;int mc_trapno;int mc_err;int mc_eip;int mc_cs;int mc_eflags;int mc_esp;int mc_ss;int mc_fpregs[28];int __spare__[17];};
# 51
typedef struct Cyc___mcontext Cyc_mcontext_t;struct Cyc___ucontext{struct Cyc___sigset uc_sigmask;struct Cyc___mcontext uc_mcontext;struct Cyc___ucontext*uc_link;struct Cyc_sigaltstack uc_stack;int __spare__[8];};
# 78
typedef struct Cyc___ucontext Cyc_ucontext_t;
# 92
int Cyc_sigaltstack(const struct Cyc_sigaltstack*,struct Cyc_sigaltstack*);
# 249
typedef void(*Cyc_sigarg_t)(int);
void Cyc_SIG_DFL(int);
void Cyc_SIG_ERR(int);
void Cyc_SIG_IGN(int);
# 257
void(*Cyc_signal(int,void(*)(int)))(int);
# 259
int Cyc_sigaction(int,struct Cyc_sigaction*,struct Cyc_sigaction*);
# 192 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
void(*signal_SIG_DFL(int))(int);
void(*signal_SIG_ERR(int))(int);
# 197
void(*signal_SIG_IGN(int))(int);
void(*signal_SIG_HANDLER(int,void(*)(int)))(int);
# 200
void(*Cyc_signal(int a,void(*b)(int)))(int){
if(b == Cyc_SIG_DFL)return signal_SIG_DFL(a);
if(b == Cyc_SIG_ERR)return signal_SIG_ERR(a);
# 206
if(b == Cyc_SIG_IGN)return signal_SIG_IGN(a);
return signal_SIG_HANDLER(a,b);}
# 211
int sigaction(int,const struct Cyc_sigaction*,struct Cyc_sigaction*);
# 213
int sigaction_wrap(struct Cyc_sigaction*);
int sigaction_unwrap(struct Cyc_sigaction*);
# 216
int Cyc_sigaction(int sig,struct Cyc_sigaction*act,struct Cyc_sigaction*oact){
# 218
if(act != 0)sigaction_unwrap(act);{
int ret=sigaction(sig,(const struct Cyc_sigaction*)act,oact);
# 222
if(act != 0)sigaction_wrap(act);
if(oact != 0)sigaction_wrap(oact);
return ret;};}
# 9 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/stddef.h"
typedef int Cyc_ptrdiff_t;
# 13
typedef int Cyc_wchar_t;
# 17 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/stdio.h"
typedef int Cyc_fpos_t;struct Cyc___cycFILE;struct  __abstractFILE;
# 81
struct Cyc___cycFILE*Cyc_fromCfile(struct  __abstractFILE*cf);
# 105
void Cyc_clearerr(struct Cyc___cycFILE*);
# 110
int Cyc_fclose(struct Cyc___cycFILE*);
# 113
struct Cyc___cycFILE*Cyc_fdopen(int,const char*);
# 115
int Cyc_feof(struct Cyc___cycFILE*);
# 117
int Cyc_ferror(struct Cyc___cycFILE*);
# 119
int Cyc_fflush(struct Cyc___cycFILE*);
# 121
int Cyc_fgetc(struct Cyc___cycFILE*);
# 123
int Cyc_fgetpos(struct Cyc___cycFILE*,int*);
# 125
struct _dyneither_ptr Cyc_fgets(struct _dyneither_ptr,int,struct Cyc___cycFILE*);
# 127
int Cyc_fileno(struct Cyc___cycFILE*);
# 130
void Cyc_flockfile(struct Cyc___cycFILE*);
# 133
struct Cyc___cycFILE*Cyc_fopen(const char*,const char*);
# 139
int Cyc_fputc(int,struct Cyc___cycFILE*);
# 141
int Cyc_fputs(const char*,struct Cyc___cycFILE*);
# 143
unsigned long Cyc_fread(struct _dyneither_ptr,unsigned long,unsigned long,struct Cyc___cycFILE*);
# 145
struct Cyc___cycFILE*Cyc_freopen(const char*,const char*,struct Cyc___cycFILE*);
# 169
int Cyc_fseek(struct Cyc___cycFILE*,long,int);
# 172
int Cyc_fseeko(struct Cyc___cycFILE*,int,int);
# 175
int Cyc_fsetpos(struct Cyc___cycFILE*,const int*);
# 177
long Cyc_ftell(struct Cyc___cycFILE*);
# 180
int Cyc_ftello(struct Cyc___cycFILE*);
# 184
int Cyc_ftrylockfile(struct Cyc___cycFILE*);
# 188
void Cyc_funlockfile(struct Cyc___cycFILE*);
# 191
unsigned long Cyc_fwrite(struct _dyneither_ptr,unsigned long,unsigned long,struct Cyc___cycFILE*);
# 193
int Cyc_getc(struct Cyc___cycFILE*);
# 195
int Cyc_getchar();
# 201
int Cyc_pclose(struct Cyc___cycFILE*);
# 206
struct Cyc___cycFILE*Cyc_popen(const char*,const char*);
# 212
int Cyc_putc(int,struct Cyc___cycFILE*);
# 222
void Cyc_rewind(struct Cyc___cycFILE*);
# 234
int Cyc_setvbuf(struct Cyc___cycFILE*,struct _dyneither_ptr,int,unsigned long);
# 238
void Cyc_setbuf(struct Cyc___cycFILE*,struct _dyneither_ptr);
# 273
int Cyc_ungetc(int,struct Cyc___cycFILE*);
# 303
int Cyc_getw(struct Cyc___cycFILE*);
# 306
int Cyc_putw(int,struct Cyc___cycFILE*);
# 322
struct Cyc___cycFILE*Cyc_file_open(struct _dyneither_ptr,struct _dyneither_ptr);
void Cyc_file_close(struct Cyc___cycFILE*);struct  __abstractFILE;
# 238 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
typedef struct  __abstractFILE Cyc_Cstdio___cFILE;struct Cyc___cycFILE{struct  __abstractFILE*file;};
# 244
struct Cyc___cycFILE*Cyc_fromCfile(struct  __abstractFILE*cf){
struct Cyc___cycFILE*_tmpA0;return(unsigned int)cf?(_tmpA0=_cycalloc(sizeof(*_tmpA0)),((_tmpA0->file=cf,_tmpA0))): 0;}
# 249
void clearerr(struct  __abstractFILE*);
# 251
void Cyc_clearerr(struct Cyc___cycFILE*f){
return clearerr(f->file);}
# 256
int fclose(struct  __abstractFILE*);
# 258
int Cyc_fclose(struct Cyc___cycFILE*f){
return fclose(f->file);}
# 263
struct  __abstractFILE*fdopen(int,const char*);
# 265
struct Cyc___cycFILE*Cyc_fdopen(int i,const char*s){
struct  __abstractFILE*_tmp11=fdopen(i,s);
# 268
struct Cyc___cycFILE*_tmpA1;return(unsigned int)_tmp11?(_tmpA1=_cycalloc(sizeof(*_tmpA1)),((_tmpA1->file=_tmp11,_tmpA1))): 0;}
# 272
int feof(struct  __abstractFILE*);
# 274
int Cyc_feof(struct Cyc___cycFILE*f){
return feof(f->file);}
# 279
int ferror(struct  __abstractFILE*);
# 281
int Cyc_ferror(struct Cyc___cycFILE*f){
return ferror(f->file);}
# 286
int fflush(struct  __abstractFILE*);
# 288
int Cyc_fflush(struct Cyc___cycFILE*f){
if((unsigned int)f)
return fflush(f->file);else{
return fflush(0);}}
# 295
int fgetc(struct  __abstractFILE*);
# 297
int Cyc_fgetc(struct Cyc___cycFILE*f){
return fgetc(f->file);}
# 302
int fgetpos(struct  __abstractFILE*,int*);
# 304
int Cyc_fgetpos(struct Cyc___cycFILE*f,int*x){
return fgetpos(f->file,x);}
# 309
char*fgets(char*,int,struct  __abstractFILE*);static char _tmp14[30]="fgets called with NULL string";
# 311
static struct Cyc_Core_Failure_exn_struct Cyc___fgets_failure_1={Cyc_Core_Failure,{_tmp14,_tmp14,_tmp14 + 30}};static char _tmp16[27]="fgets: buffer insufficient";
# 313
static struct Cyc_Core_Failure_exn_struct Cyc___fgets_failure_2={Cyc_Core_Failure,{_tmp16,_tmp16,_tmp16 + 27}};
# 315
struct _dyneither_ptr Cyc_fgets(struct _dyneither_ptr s,int n,struct Cyc___cycFILE*f){
if(!((unsigned int)s.curr))(int)_throw((void*)& Cyc___fgets_failure_1);{
char*result;
char*buffer=(char*)_check_null(_untag_dyneither_ptr(s,sizeof(char),1));
unsigned int len=_get_dyneither_size(s,sizeof(char));
if(len < n)(int)_throw((void*)& Cyc___fgets_failure_2);
# 322
result=fgets(buffer,n,f->file);
if(result == 0)
return _tag_dyneither(0,0,0);else{
# 326
return s;}};}
# 330
int fileno(struct  __abstractFILE*);
# 332
int Cyc_fileno(struct Cyc___cycFILE*f){
return fileno(f->file);}
# 338
void flockfile(struct  __abstractFILE*);
# 340
void Cyc_flockfile(struct Cyc___cycFILE*f){
return flockfile(f->file);}
# 346
struct  __abstractFILE*fopen(const char*,const char*);
# 348
struct Cyc___cycFILE*Cyc_fopen(const char*name,const char*type){
struct  __abstractFILE*_tmp17=fopen(name,type);
# 351
struct Cyc___cycFILE*_tmpA2;return(unsigned int)_tmp17?(_tmpA2=_cycalloc(sizeof(*_tmpA2)),((_tmpA2->file=_tmp17,_tmpA2))): 0;}
# 355
int fputc(int,struct  __abstractFILE*);
# 357
int Cyc_fputc(int x,struct Cyc___cycFILE*f){
return fputc(x,f->file);}
# 362
int fputs(const char*,struct  __abstractFILE*);
# 364
int Cyc_fputs(const char*x,struct Cyc___cycFILE*f){
return fputs(x,f->file);}
# 369
unsigned long fread(char*,unsigned long,unsigned long,struct  __abstractFILE*);static char _tmp1A[27]="fread: buffer insufficient";
# 371
static struct Cyc_Core_Failure_exn_struct Cyc___fread_failure={Cyc_Core_Failure,{_tmp1A,_tmp1A,_tmp1A + 27}};
# 373
unsigned long Cyc_fread(struct _dyneither_ptr ptr,unsigned long size,unsigned long nmemb,struct Cyc___cycFILE*f){
if(size * nmemb > _get_dyneither_size(ptr,sizeof(char)))(int)_throw((void*)& Cyc___fread_failure);
return fread((char*)_check_null(_untag_dyneither_ptr(ptr,sizeof(char),1)),size,nmemb,f->file);}
# 379
struct  __abstractFILE*freopen(const char*,const char*,struct  __abstractFILE*);
# 382
struct Cyc___cycFILE*Cyc_freopen(const char*filename,const char*modes,struct Cyc___cycFILE*f){
# 384
struct  __abstractFILE*_tmp1B=freopen(filename,modes,f->file);
# 386
struct Cyc___cycFILE*_tmpA3;return(unsigned int)_tmp1B?(_tmpA3=_cycalloc(sizeof(*_tmpA3)),((_tmpA3->file=_tmp1B,_tmpA3))): 0;}
# 390
int fseek(struct  __abstractFILE*,long,int);
# 392
int Cyc_fseek(struct Cyc___cycFILE*a,long b,int c){
return fseek(a->file,b,c);}
# 398
int fseeko(struct  __abstractFILE*,int,int);
# 400
int Cyc_fseeko(struct Cyc___cycFILE*a,int b,int c){
return fseeko(a->file,b,c);}
# 406
int fsetpos(struct  __abstractFILE*,const int*);
# 408
int Cyc_fsetpos(struct Cyc___cycFILE*f,const int*b){
return fsetpos(f->file,b);}
# 413
long ftell(struct  __abstractFILE*);
# 415
long Cyc_ftell(struct Cyc___cycFILE*f){
return ftell(f->file);}
# 421
int ftello(struct  __abstractFILE*);
# 423
int Cyc_ftello(struct Cyc___cycFILE*f){
return ftello(f->file);}
# 430
int ftrylockfile(struct  __abstractFILE*);
# 432
int Cyc_ftrylockfile(struct Cyc___cycFILE*f){
return ftrylockfile(f->file);}
# 439
void funlockfile(struct  __abstractFILE*);
# 441
void Cyc_funlockfile(struct Cyc___cycFILE*f){
return funlockfile(f->file);}
# 447
unsigned long fwrite(const char*,unsigned long,unsigned long,struct  __abstractFILE*);static char _tmp1E[31]="fwrite called with NULL string";
# 449
static struct Cyc_Core_Failure_exn_struct Cyc___fwrite_failure_1={Cyc_Core_Failure,{_tmp1E,_tmp1E,_tmp1E + 31}};static char _tmp20[28]="fwrite: buffer insufficient";
# 451
static struct Cyc_Core_Failure_exn_struct Cyc___fwrite_failure_2={Cyc_Core_Failure,{_tmp20,_tmp20,_tmp20 + 28}};
# 453
unsigned long Cyc_fwrite(struct _dyneither_ptr ptr,unsigned long size,unsigned long nmemb,struct Cyc___cycFILE*f){
if(!((unsigned int)ptr.curr))(int)_throw((void*)& Cyc___fwrite_failure_1);else{
# 456
if(size * nmemb > _get_dyneither_size(ptr,sizeof(char)))(int)_throw((void*)& Cyc___fwrite_failure_2);
return fwrite((const char*)_untag_dyneither_ptr(ptr,sizeof(char),1),size,nmemb,f->file);}}
# 462
int getc(struct  __abstractFILE*);
# 464
int Cyc_getc(struct Cyc___cycFILE*f){
return getc(f->file);}
# 469
int getchar();
# 471
int Cyc_getchar(){
return getchar();}
# 476
int pclose(struct  __abstractFILE*);
# 478
int Cyc_pclose(struct Cyc___cycFILE*f){
return pclose(f->file);}
# 483
struct  __abstractFILE*popen(const char*,const char*);
# 485
struct Cyc___cycFILE*Cyc_popen(const char*name,const char*type){
struct  __abstractFILE*_tmp21=popen(name,type);
# 488
struct Cyc___cycFILE*_tmpA4;return(unsigned int)_tmp21?(_tmpA4=_cycalloc(sizeof(*_tmpA4)),((_tmpA4->file=_tmp21,_tmpA4))): 0;}
# 492
int putc(int,struct  __abstractFILE*);
# 494
int Cyc_putc(int x,struct Cyc___cycFILE*f){
return putc(x,f->file);}
# 499
void rewind(struct  __abstractFILE*);
# 501
void Cyc_rewind(struct Cyc___cycFILE*f){
return rewind(f->file);}
# 506
int setvbuf(struct  __abstractFILE*,char*,int,unsigned long);static char _tmp24[24]="setvbuf: buffer is NULL";
# 508
static struct Cyc_Core_Failure_exn_struct Cyc___setvbuf_failure_1={Cyc_Core_Failure,{_tmp24,_tmp24,_tmp24 + 24}};static char _tmp26[29]="setvbuf: buffer insufficient";
# 510
static struct Cyc_Core_Failure_exn_struct Cyc___setvbuf_failure_2={Cyc_Core_Failure,{_tmp26,_tmp26,_tmp26 + 29}};
# 512
int Cyc_setvbuf(struct Cyc___cycFILE*f,struct _dyneither_ptr buf,int type,unsigned long size){
if(!((unsigned int)buf.curr))(int)_throw((void*)& Cyc___setvbuf_failure_1);
if(_get_dyneither_size(buf,sizeof(char))< size)(int)_throw((void*)& Cyc___setvbuf_failure_2);
return setvbuf(f->file,(char*)_check_null(_untag_dyneither_ptr(buf,sizeof(char),1)),type,size);}
# 518
void Cyc_setbuf(struct Cyc___cycFILE*f,struct _dyneither_ptr buf){
Cyc_setvbuf(f,buf,(unsigned int)buf.curr?0: 2,1024);
return;}
# 548
int ungetc(int,struct  __abstractFILE*);
# 550
int Cyc_ungetc(int x,struct Cyc___cycFILE*f){
return ungetc(x,f->file);}
# 555
int getw(struct  __abstractFILE*);
# 557
int Cyc_getw(struct Cyc___cycFILE*f){
return getw(f->file);}
# 562
int putw(int,struct  __abstractFILE*);
# 564
int Cyc_putw(int x,struct Cyc___cycFILE*f){
return putw(x,f->file);}char Cyc_FileCloseError[15]="FileCloseError";char Cyc_FileOpenError[14]="FileOpenError";struct Cyc___cycFILE*Cyc_file_open(struct _dyneither_ptr fname,struct _dyneither_ptr mode);static void _tmpAA(struct _dyneither_ptr*fname,unsigned int*_tmpA9,unsigned int*_tmpA8,char**_tmpA6){for(*_tmpA9=0;*_tmpA9 < *_tmpA8;(*_tmpA9)++){(*_tmpA6)[*_tmpA9]=(char)((const char*)(*fname).curr)[(int)*_tmpA9];}}
# 573
struct Cyc___cycFILE*Cyc_file_open(struct _dyneither_ptr fname,struct _dyneither_ptr mode){
struct Cyc___cycFILE*f=Cyc_fopen((const char*)_untag_dyneither_ptr(fname,sizeof(char),1),(const char*)_untag_dyneither_ptr(mode,sizeof(char),1));
if(f == 0){
unsigned int _tmpA9;unsigned int _tmpA8;struct _dyneither_ptr _tmpA7;char*_tmpA6;unsigned int _tmpA5;struct _dyneither_ptr fn=(_tmpA5=_get_dyneither_size(fname,sizeof(char)),((_tmpA6=(char*)_cycalloc_atomic(_check_times(sizeof(char),_tmpA5 + 1)),((_tmpA7=_tag_dyneither(_tmpA6,sizeof(char),_tmpA5 + 1),((((_tmpA8=_tmpA5,((_tmpAA(& fname,& _tmpA9,& _tmpA8,& _tmpA6),_tmpA6[_tmpA8]=(char)0)))),_tmpA7)))))));
struct Cyc_FileOpenError_exn_struct _tmpAD;struct Cyc_FileOpenError_exn_struct*_tmpAC;(int)_throw((void*)((_tmpAC=_cycalloc(sizeof(*_tmpAC)),((_tmpAC[0]=((_tmpAD.tag=Cyc_FileOpenError,((_tmpAD.f1=fn,_tmpAD)))),_tmpAC)))));}
# 579
return f;}
# 582
struct Cyc_FileCloseError_exn_struct Cyc_FileCloseError_val={Cyc_FileCloseError};
void Cyc_file_close(struct Cyc___cycFILE*f){
if(Cyc_fclose(f)!= 0)(int)_throw((void*)& Cyc_FileCloseError_val);}
# 13 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/stdlib.h"
typedef struct {int quot;int rem;}Cyc_div_t;
# 18
typedef struct {long quot;long rem;}Cyc_ldiv_t;
# 105
void Cyc_free(struct _dyneither_ptr);
# 130
void Cyc_qsort(struct _dyneither_ptr,unsigned long,unsigned int,int(*)(const void*,const void*));
# 590 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
void Cyc_free(struct _dyneither_ptr ptr){;}
# 593
void qsort(void*,unsigned long,unsigned long,int(*)(const void*,const void*));static char _tmp2F[23]="qsort called with NULL";
# 596
static struct Cyc_Core_Failure_exn_struct Cyc___qsort_failure_1={Cyc_Core_Failure,{_tmp2F,_tmp2F,_tmp2F + 23}};static char _tmp31[42]="qsort called with insufficient array size";
# 598
static struct Cyc_Core_Failure_exn_struct Cyc___qsort_failure_2={Cyc_Core_Failure,{_tmp31,_tmp31,_tmp31 + 42}};
# 600
void Cyc_qsort(struct _dyneither_ptr tab,unsigned long nmemb,unsigned int szmemb,int(*compar)(const void*,const void*)){
# 602
if(!((unsigned int)tab.curr))(int)_throw((void*)& Cyc___qsort_failure_1);
if(_get_dyneither_size(tab,sizeof(void))< nmemb)(int)_throw((void*)& Cyc___qsort_failure_2);
qsort((void*)_untag_dyneither_ptr(tab,sizeof(void),1),nmemb,szmemb,compar);}
# 13 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/ipc.h"
typedef unsigned short Cyc_ushort;
# 25
typedef unsigned int Cyc_gid_t;
# 29
typedef long Cyc_key_t;
# 37
typedef unsigned int Cyc_uid_t;struct Cyc_ipc_perm{unsigned short cuid;unsigned short cgid;unsigned short uid;unsigned short gid;unsigned short mode;unsigned short seq;long key;};
# 49 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/mman.h"
struct _dyneither_ptr Cyc_mmap(struct _dyneither_ptr,unsigned long length,int prot,int flags,int fd,int offset);
# 53
int Cyc_munmap(struct _dyneither_ptr start,unsigned long length);
# 620 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
char*__stub_mmap(char*start,unsigned long length,int prot,int flags,int fd,int offset);
# 623
int munmap(const char*start,unsigned long length);static char _tmp33[42]="mmap called with illegal start/prot/flags";
# 625
static struct Cyc_Core_Failure_exn_struct Cyc___mmap_failure={Cyc_Core_Failure,{_tmp33,_tmp33,_tmp33 + 42}};
# 627
struct _dyneither_ptr Cyc_mmap(struct _dyneither_ptr ignored,unsigned long length,int prot,int flags,int fd,int offset){
# 630
if(prot == 4  || 
flags & 2  && flags & 1)
# 636
(int)_throw((void*)& Cyc___mmap_failure);else{
if(flags & 16)
return _tag_dyneither(0,0,0);else{
# 640
return wrap_Cbuffer_as_buffer(
__stub_mmap(0,length,prot,flags,fd,offset),length);}}}
# 647
int Cyc_munmap(struct _dyneither_ptr start,unsigned long length){
# 649
return munmap((const char*)_check_null(_untag_dyneither_ptr(start,sizeof(char),1)),length);}
# 9 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/resource.h"
typedef unsigned int Cyc___uint64_t;
# 13
typedef int Cyc_int64_t;
# 17
typedef unsigned int Cyc_u_int64_t;
# 21
typedef unsigned int Cyc_u_quad_t;
# 25
typedef int Cyc_quad_t;
# 29
typedef int Cyc_rlim_t;struct Cyc_timeval{long tv_sec;long tv_usec;};struct Cyc_rusage{struct Cyc_timeval ru_utime;struct Cyc_timeval ru_stime;long ru_maxrss;long ru_ixrss;long ru_idrss;long ru_isrss;long ru_minflt;long ru_majflt;long ru_nswap;long ru_inblock;long ru_oublock;long ru_msgsnd;long ru_msgrcv;long ru_nsignals;long ru_nvcsw;long ru_nivcsw;};struct Cyc_rlimit{int rlim_cur;int rlim_max;};
# 106
typedef int Cyc_id_t;
# 5 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/select.h"
typedef long Cyc_time_t;
# 9
typedef unsigned long Cyc_fd_mask;struct Cyc_fd_set{unsigned long fds_bits[(1024 + (sizeof(unsigned long)* 8 - 1))/ (sizeof(unsigned long)* 8)];};
# 13
typedef struct Cyc_fd_set Cyc_fd_set;struct Cyc_timespec{long tv_sec;long tv_nsec;};
# 77
int Cyc_select(int a,struct Cyc_fd_set*b,struct Cyc_fd_set*c,struct Cyc_fd_set*d,struct Cyc_timeval*e);
# 83
void Cyc_FD_CLR(int,struct Cyc_fd_set*);
int Cyc_FD_ISSET(int,struct Cyc_fd_set*);
void Cyc_FD_SET(int,struct Cyc_fd_set*);
void Cyc_FD_ZERO(struct Cyc_fd_set*);
# 662 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
int select(int,struct Cyc_fd_set*,struct Cyc_fd_set*,struct Cyc_fd_set*,struct Cyc_timeval*);
# 665
extern int Cyc_select(int a,struct Cyc_fd_set*b,struct Cyc_fd_set*c,struct Cyc_fd_set*d,struct Cyc_timeval*e){
# 668
if(a < 0  || a > 1024){
*((int*)_check_null(__CYCLONE_ERRNO()))=22;
return - 1;}
# 672
return select(a,b,c,d,e);}
# 676
void __stub_FD_CLR(int,struct Cyc_fd_set*);
int __stub_FD_ISSET(int,struct Cyc_fd_set*);
void __stub_FD_SET(int,struct Cyc_fd_set*);
void __stub_FD_ZERO(struct Cyc_fd_set*);
# 681
void Cyc_FD_CLR(int a,struct Cyc_fd_set*b){
if(a < 0  || a > 1024)return;
return __stub_FD_CLR(a,b);}
# 685
int Cyc_FD_ISSET(int a,struct Cyc_fd_set*b){
if(a < 0  || a > 1024)return 0;
return __stub_FD_ISSET(a,b);}
# 689
void Cyc_FD_SET(int a,struct Cyc_fd_set*b){
if(a < 0  || a > 1024)return;
return __stub_FD_SET(a,b);}
# 693
void Cyc_FD_ZERO(struct Cyc_fd_set*a){
return __stub_FD_ZERO(a);}
# 13 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/socket.h"
typedef int Cyc_ssize_t;struct Cyc_cmsghdr;struct Cyc_linger{int l_onoff;int l_linger;};struct Cyc_sockaddr{unsigned char sa_len;unsigned char sa_family;char sa_data[14];};struct Cyc_SA_sockaddr_in_SockAddr_struct{int tag;struct Cyc_sockaddr_in*f1;};struct Cyc_SA_socklenptr_SockAddr_struct{int tag;unsigned int*f1;};struct Cyc_SA_socklen_SockAddr_struct{int tag;unsigned int f1;};
# 211
typedef void*Cyc_SA;struct Cyc_SO_int_SockOpt_struct{int tag;int*f1;};struct Cyc_SO_timeval_SockOpt_struct{int tag;struct Cyc_timeval*f1;};struct Cyc_SO_socklenptr_SockOpt_struct{int tag;unsigned int*f1;};struct Cyc_SO_socklen_SockOpt_struct{int tag;unsigned int f1;};
# 221
typedef void*Cyc_SO;
# 223
int Cyc_accept(int fd,struct _dyneither_ptr);extern char Cyc_SocketError[12];struct Cyc_SocketError_exn_struct{char*tag;};
# 227
int Cyc_bind(int fd,struct _dyneither_ptr);
# 229
int Cyc_connect(int fd,struct _dyneither_ptr);
# 231
int Cyc_getpeername(int fd,struct _dyneither_ptr);
# 233
int Cyc_getsockname(int fd,struct _dyneither_ptr);
# 235
int Cyc_getsockopt(int fd,int level,int optname,struct _dyneither_ptr);
# 239
int Cyc_recv(int fd,struct _dyneither_ptr buf,unsigned long n,int flags);
# 241
int Cyc_recvfrom(int fd,struct _dyneither_ptr buf,unsigned long n,int flags,struct _dyneither_ptr);
# 244
int Cyc_send(int fd,struct _dyneither_ptr buf,unsigned long n,int flags);
# 246
int Cyc_sendto(int fd,struct _dyneither_ptr buf,unsigned long n,int flags,struct _dyneither_ptr);
# 249
int Cyc_setsockopt(int fd,int level,int optname,struct _dyneither_ptr);char Cyc_SocketError[12]="SocketError";
# 703 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
struct Cyc_SocketError_exn_struct Cyc_SocketError_val={Cyc_SocketError};
# 706
int accept_in(int,const struct Cyc_sockaddr_in*,unsigned int*);struct _tuple0{void*f1;void*f2;};
# 708
int Cyc_accept(int fd,struct _dyneither_ptr ap){
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpAE;struct _tuple0 _tmp35=(_tmpAE.f1=((void**)ap.curr)[0],((_tmpAE.f2=((void**)ap.curr)[1],_tmpAE)));struct _tuple0 _tmp36=_tmp35;struct Cyc_sockaddr_in*_tmp38;unsigned int*_tmp3A;_LL6:{struct Cyc_SA_sockaddr_in_SockAddr_struct*_tmp37=(struct Cyc_SA_sockaddr_in_SockAddr_struct*)_tmp36.f1;if(_tmp37->tag != 0)goto _LL8;else{_tmp38=_tmp37->f1;}}{struct Cyc_SA_socklenptr_SockAddr_struct*_tmp39=(struct Cyc_SA_socklenptr_SockAddr_struct*)_tmp36.f2;if(_tmp39->tag != 1)goto _LL8;else{_tmp3A=_tmp39->f1;}};_LL7:
# 712
 return accept_in(fd,(const struct Cyc_sockaddr_in*)_tmp38,_tmp3A);_LL8:;_LL9:
(int)_throw((void*)& Cyc_SocketError_val);_LL5:;};}
# 718
int bind_in(int,const struct Cyc_sockaddr_in*,unsigned int);
# 720
int Cyc_bind(int fd,struct _dyneither_ptr ap){
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpAF;struct _tuple0 _tmp3C=(_tmpAF.f1=((void**)ap.curr)[0],((_tmpAF.f2=((void**)ap.curr)[1],_tmpAF)));struct _tuple0 _tmp3D=_tmp3C;struct Cyc_sockaddr_in*_tmp3F;unsigned int _tmp41;_LLB:{struct Cyc_SA_sockaddr_in_SockAddr_struct*_tmp3E=(struct Cyc_SA_sockaddr_in_SockAddr_struct*)_tmp3D.f1;if(_tmp3E->tag != 0)goto _LLD;else{_tmp3F=_tmp3E->f1;}}{struct Cyc_SA_socklen_SockAddr_struct*_tmp40=(struct Cyc_SA_socklen_SockAddr_struct*)_tmp3D.f2;if(_tmp40->tag != 2)goto _LLD;else{_tmp41=_tmp40->f1;}};_LLC:
# 724
 return bind_in(fd,(const struct Cyc_sockaddr_in*)_tmp3F,_tmp41);_LLD:;_LLE:
(int)_throw((void*)& Cyc_SocketError_val);_LLA:;};}
# 730
int connect_in(int,const struct Cyc_sockaddr_in*,unsigned int);
# 732
int Cyc_connect(int fd,struct _dyneither_ptr ap){
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpB0;struct _tuple0 _tmp43=(_tmpB0.f1=((void**)ap.curr)[0],((_tmpB0.f2=((void**)ap.curr)[1],_tmpB0)));struct _tuple0 _tmp44=_tmp43;struct Cyc_sockaddr_in*_tmp46;unsigned int _tmp48;_LL10:{struct Cyc_SA_sockaddr_in_SockAddr_struct*_tmp45=(struct Cyc_SA_sockaddr_in_SockAddr_struct*)_tmp44.f1;if(_tmp45->tag != 0)goto _LL12;else{_tmp46=_tmp45->f1;}}{struct Cyc_SA_socklen_SockAddr_struct*_tmp47=(struct Cyc_SA_socklen_SockAddr_struct*)_tmp44.f2;if(_tmp47->tag != 2)goto _LL12;else{_tmp48=_tmp47->f1;}};_LL11:
# 736
 return connect_in(fd,(const struct Cyc_sockaddr_in*)_tmp46,_tmp48);_LL12:;_LL13:
(int)_throw((void*)& Cyc_SocketError_val);_LLF:;};}
# 742
int getpeername_in(int,const struct Cyc_sockaddr_in*,unsigned int*);
# 744
int Cyc_getpeername(int fd,struct _dyneither_ptr ap){
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpB1;struct _tuple0 _tmp4A=(_tmpB1.f1=((void**)ap.curr)[0],((_tmpB1.f2=((void**)ap.curr)[1],_tmpB1)));struct _tuple0 _tmp4B=_tmp4A;struct Cyc_sockaddr_in*_tmp4D;unsigned int*_tmp4F;_LL15:{struct Cyc_SA_sockaddr_in_SockAddr_struct*_tmp4C=(struct Cyc_SA_sockaddr_in_SockAddr_struct*)_tmp4B.f1;if(_tmp4C->tag != 0)goto _LL17;else{_tmp4D=_tmp4C->f1;}}{struct Cyc_SA_socklenptr_SockAddr_struct*_tmp4E=(struct Cyc_SA_socklenptr_SockAddr_struct*)_tmp4B.f2;if(_tmp4E->tag != 1)goto _LL17;else{_tmp4F=_tmp4E->f1;}};_LL16:
# 748
 return getpeername_in(fd,(const struct Cyc_sockaddr_in*)_tmp4D,_tmp4F);_LL17:;_LL18:
(int)_throw((void*)& Cyc_SocketError_val);_LL14:;};}
# 754
int getsockname_in(int,const struct Cyc_sockaddr_in*,unsigned int*);
# 756
int Cyc_getsockname(int fd,struct _dyneither_ptr ap){
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpB2;struct _tuple0 _tmp51=(_tmpB2.f1=((void**)ap.curr)[0],((_tmpB2.f2=((void**)ap.curr)[1],_tmpB2)));struct _tuple0 _tmp52=_tmp51;struct Cyc_sockaddr_in*_tmp54;unsigned int*_tmp56;_LL1A:{struct Cyc_SA_sockaddr_in_SockAddr_struct*_tmp53=(struct Cyc_SA_sockaddr_in_SockAddr_struct*)_tmp52.f1;if(_tmp53->tag != 0)goto _LL1C;else{_tmp54=_tmp53->f1;}}{struct Cyc_SA_socklenptr_SockAddr_struct*_tmp55=(struct Cyc_SA_socklenptr_SockAddr_struct*)_tmp52.f2;if(_tmp55->tag != 1)goto _LL1C;else{_tmp56=_tmp55->f1;}};_LL1B:
# 760
 return getsockname_in(fd,(const struct Cyc_sockaddr_in*)_tmp54,_tmp56);_LL1C:;_LL1D:
(int)_throw((void*)& Cyc_SocketError_val);_LL19:;};}
# 766
int getsockopt_int(int,int,int,int*,unsigned int*);
int getsockopt_timeval(int,int,int,struct Cyc_timeval*,unsigned int*);
# 769
int Cyc_getsockopt(int fd,int level,int optname,struct _dyneither_ptr ap){
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpB3;struct _tuple0 _tmp58=(_tmpB3.f1=((void**)ap.curr)[0],((_tmpB3.f2=((void**)ap.curr)[1],_tmpB3)));struct _tuple0 _tmp59=_tmp58;int*_tmp5B;unsigned int*_tmp5D;int*_tmp5F;int*_tmp61;struct Cyc_timeval*_tmp63;unsigned int*_tmp65;struct Cyc_timeval*_tmp67;int*_tmp69;_LL1F:{struct Cyc_SO_int_SockOpt_struct*_tmp5A=(struct Cyc_SO_int_SockOpt_struct*)_tmp59.f1;if(_tmp5A->tag != 0)goto _LL21;else{_tmp5B=_tmp5A->f1;}}{struct Cyc_SO_socklenptr_SockOpt_struct*_tmp5C=(struct Cyc_SO_socklenptr_SockOpt_struct*)_tmp59.f2;if(_tmp5C->tag != 2)goto _LL21;else{_tmp5D=_tmp5C->f1;}};_LL20:
# 773
 return getsockopt_int(fd,level,optname,_tmp5B,_tmp5D);_LL21:{struct Cyc_SO_int_SockOpt_struct*_tmp5E=(struct Cyc_SO_int_SockOpt_struct*)_tmp59.f1;if(_tmp5E->tag != 0)goto _LL23;else{_tmp5F=_tmp5E->f1;}}{struct Cyc_SO_int_SockOpt_struct*_tmp60=(struct Cyc_SO_int_SockOpt_struct*)_tmp59.f2;if(_tmp60->tag != 0)goto _LL23;else{_tmp61=_tmp60->f1;}};_LL22:
# 775
 return getsockopt_int(fd,level,optname,_tmp5F,(unsigned int*)_tmp61);_LL23:{struct Cyc_SO_timeval_SockOpt_struct*_tmp62=(struct Cyc_SO_timeval_SockOpt_struct*)_tmp59.f1;if(_tmp62->tag != 1)goto _LL25;else{_tmp63=_tmp62->f1;}}{struct Cyc_SO_socklenptr_SockOpt_struct*_tmp64=(struct Cyc_SO_socklenptr_SockOpt_struct*)_tmp59.f2;if(_tmp64->tag != 2)goto _LL25;else{_tmp65=_tmp64->f1;}};_LL24:
# 777
 return getsockopt_timeval(fd,level,optname,_tmp63,_tmp65);_LL25:{struct Cyc_SO_timeval_SockOpt_struct*_tmp66=(struct Cyc_SO_timeval_SockOpt_struct*)_tmp59.f1;if(_tmp66->tag != 1)goto _LL27;else{_tmp67=_tmp66->f1;}}{struct Cyc_SO_int_SockOpt_struct*_tmp68=(struct Cyc_SO_int_SockOpt_struct*)_tmp59.f2;if(_tmp68->tag != 0)goto _LL27;else{_tmp69=_tmp68->f1;}};_LL26:
# 779
 return getsockopt_timeval(fd,level,optname,_tmp67,(unsigned int*)_tmp69);_LL27:;_LL28:
(int)_throw((void*)& Cyc_SocketError_val);_LL1E:;};}
# 785
int recv_wrapped(int,struct _dyneither_ptr,unsigned long,int);
# 789
int Cyc_recv(int fd,struct _dyneither_ptr buf,unsigned long n,int flags){
return recv_wrapped(fd,buf,n,flags);}
# 794
int recvfrom_in(int,struct _dyneither_ptr,unsigned long,int,const struct Cyc_sockaddr_in*,unsigned int*);
# 797
int Cyc_recvfrom(int fd,struct _dyneither_ptr buf,unsigned long n,int flags,struct _dyneither_ptr ap){
# 799
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpB4;struct _tuple0 _tmp6B=(_tmpB4.f1=((void**)ap.curr)[0],((_tmpB4.f2=((void**)ap.curr)[1],_tmpB4)));struct _tuple0 _tmp6C=_tmp6B;struct Cyc_sockaddr_in*_tmp6E;unsigned int*_tmp70;_LL2A:{struct Cyc_SA_sockaddr_in_SockAddr_struct*_tmp6D=(struct Cyc_SA_sockaddr_in_SockAddr_struct*)_tmp6C.f1;if(_tmp6D->tag != 0)goto _LL2C;else{_tmp6E=_tmp6D->f1;}}{struct Cyc_SA_socklenptr_SockAddr_struct*_tmp6F=(struct Cyc_SA_socklenptr_SockAddr_struct*)_tmp6C.f2;if(_tmp6F->tag != 1)goto _LL2C;else{_tmp70=_tmp6F->f1;}};_LL2B:
# 802
 return recvfrom_in(fd,buf,n,flags,(const struct Cyc_sockaddr_in*)_tmp6E,_tmp70);_LL2C:;_LL2D:
(int)_throw((void*)& Cyc_SocketError_val);_LL29:;};}
# 808
int send_wrapped(int,struct _dyneither_ptr,unsigned long,int);
# 810
int Cyc_send(int fd,struct _dyneither_ptr buf,unsigned long n,int flags){
return send_wrapped(fd,buf,n,flags);}
# 815
int sendto_in(int,struct _dyneither_ptr,unsigned long,int,const struct Cyc_sockaddr_in*,unsigned int);
# 818
int Cyc_sendto(int fd,struct _dyneither_ptr buf,unsigned long n,int flags,struct _dyneither_ptr ap){
# 820
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpB5;struct _tuple0 _tmp72=(_tmpB5.f1=((void**)ap.curr)[0],((_tmpB5.f2=((void**)ap.curr)[1],_tmpB5)));struct _tuple0 _tmp73=_tmp72;struct Cyc_sockaddr_in*_tmp75;unsigned int _tmp77;_LL2F:{struct Cyc_SA_sockaddr_in_SockAddr_struct*_tmp74=(struct Cyc_SA_sockaddr_in_SockAddr_struct*)_tmp73.f1;if(_tmp74->tag != 0)goto _LL31;else{_tmp75=_tmp74->f1;}}{struct Cyc_SA_socklen_SockAddr_struct*_tmp76=(struct Cyc_SA_socklen_SockAddr_struct*)_tmp73.f2;if(_tmp76->tag != 2)goto _LL31;else{_tmp77=_tmp76->f1;}};_LL30:
# 823
 return sendto_in(fd,buf,n,flags,(const struct Cyc_sockaddr_in*)_tmp75,_tmp77);_LL31:;_LL32:
(int)_throw((void*)& Cyc_SocketError_val);_LL2E:;};}
# 829
int setsockopt_int(int,int,int,const int*,unsigned int);
int setsockopt_timeval(int,int,int,const struct Cyc_timeval*,unsigned int);
# 832
int Cyc_setsockopt(int fd,int level,int optname,struct _dyneither_ptr ap){
if(_get_dyneither_size(ap,sizeof(void*))!= 2)(int)_throw((void*)& Cyc_SocketError_val);{
struct _tuple0 _tmpB6;struct _tuple0 _tmp79=(_tmpB6.f1=((void**)ap.curr)[0],((_tmpB6.f2=((void**)ap.curr)[1],_tmpB6)));struct _tuple0 _tmp7A=_tmp79;int*_tmp7C;unsigned int _tmp7E;struct Cyc_timeval*_tmp80;unsigned int _tmp82;_LL34:{struct Cyc_SO_int_SockOpt_struct*_tmp7B=(struct Cyc_SO_int_SockOpt_struct*)_tmp7A.f1;if(_tmp7B->tag != 0)goto _LL36;else{_tmp7C=_tmp7B->f1;}}{struct Cyc_SO_socklen_SockOpt_struct*_tmp7D=(struct Cyc_SO_socklen_SockOpt_struct*)_tmp7A.f2;if(_tmp7D->tag != 3)goto _LL36;else{_tmp7E=_tmp7D->f1;}};_LL35:
# 836
 return setsockopt_int(fd,level,optname,(const int*)_tmp7C,_tmp7E);_LL36:{struct Cyc_SO_timeval_SockOpt_struct*_tmp7F=(struct Cyc_SO_timeval_SockOpt_struct*)_tmp7A.f1;if(_tmp7F->tag != 1)goto _LL38;else{_tmp80=_tmp7F->f1;}}{struct Cyc_SO_socklen_SockOpt_struct*_tmp81=(struct Cyc_SO_socklen_SockOpt_struct*)_tmp7A.f2;if(_tmp81->tag != 3)goto _LL38;else{_tmp82=_tmp81->f1;}};_LL37:
# 838
 return setsockopt_timeval(fd,level,optname,(const struct Cyc_timeval*)_tmp80,_tmp82);_LL38:;_LL39:
(int)_throw((void*)& Cyc_SocketError_val);_LL33:;};}
# 13 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/stat.h"
typedef int Cyc___int32_t;
# 21
typedef int Cyc_int32_t;
# 49
typedef unsigned short Cyc_nlink_t;
# 61
typedef unsigned int Cyc_dev_t;struct Cyc_stat{unsigned int st_dev;unsigned int st_ino;unsigned short st_mode;unsigned short st_nlink;unsigned int st_uid;unsigned int st_gid;unsigned int st_rdev;struct Cyc_timespec st_atimespec;struct Cyc_timespec st_mtimespec;struct Cyc_timespec st_ctimespec;int st_size;int st_blocks;unsigned int st_blksize;unsigned int st_flags;unsigned int st_gen;int st_lspare;int st_qspare[2];};struct Cyc_timezone{int tz_minuteswest;int tz_dsttime;};struct Cyc_itimerval{struct Cyc_timeval it_interval;struct Cyc_timeval it_value;};
# 89 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/time.h"
int Cyc_gettimeofday(struct Cyc_timeval*,struct Cyc_timezone*);
# 92
int Cyc_select(int,struct Cyc_fd_set*,struct Cyc_fd_set*,struct Cyc_fd_set*,struct Cyc_timeval*);
void Cyc_FD_CLR(int,struct Cyc_fd_set*);
int Cyc_FD_ISSET(int,struct Cyc_fd_set*);
void Cyc_FD_SET(int,struct Cyc_fd_set*);
void Cyc_FD_ZERO(struct Cyc_fd_set*);
# 849 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
int gettimeofday(struct Cyc_timeval*,struct Cyc_timezone*);
# 851
int Cyc_gettimeofday(struct Cyc_timeval*a,struct Cyc_timezone*b){
return gettimeofday(a,0);}struct Cyc_timeb{long time;unsigned short millitm;short timezone;short dstflag;};
# 5 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/times.h"
typedef unsigned long Cyc_clock_t;struct Cyc_tms{unsigned long tms_utime;unsigned long tms_stime;unsigned long tms_cutime;unsigned long tms_cstime;};
# 25 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/sys/types.h"
typedef unsigned int Cyc_u_int;
# 29
typedef unsigned long Cyc_u_long;
# 81
typedef int Cyc_clockid_t;
# 97
typedef int Cyc_timer_t;struct Cyc_sockaddr_un{unsigned char sun_len;unsigned char sun_family;char sun_path[104];};struct Cyc_utsname{char sysname[32];char nodename[32];char release[32];char version[32];char machine[32];};struct Cyc_tm{int tm_sec;int tm_min;int tm_hour;int tm_mday;int tm_mon;int tm_year;int tm_wday;int tm_yday;int tm_isdst;long tm_gmtoff;char*tm_zone;};
# 112 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/time.h"
unsigned long Cyc_strftime(struct _dyneither_ptr,unsigned long,struct _dyneither_ptr,const struct Cyc_tm*);
# 879 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
unsigned long strftime(char*,unsigned long,const char*,const struct Cyc_tm*);static char _tmp85[27]="fgets: buffer insufficient";
# 882
static struct Cyc_Core_Failure_exn_struct Cyc___strftime_failure={Cyc_Core_Failure,{_tmp85,_tmp85,_tmp85 + 27}};
# 884
unsigned long Cyc_strftime(struct _dyneither_ptr s,unsigned long maxsize,struct _dyneither_ptr fmt,const struct Cyc_tm*t){
# 886
if(maxsize > _get_dyneither_size(s,sizeof(char)))(int)_throw((void*)& Cyc___strftime_failure);
return strftime((char*)_check_null(_untag_dyneither_ptr(s,sizeof(char),1)),maxsize,(const char*)_check_null(_untag_dyneither_ptr(fmt,sizeof(char),1)),t);}
# 181 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/unistd.h"
typedef unsigned int Cyc_useconds_t;struct Cyc_option{struct _dyneither_ptr name;int has_arg;int*flag;int val;};
# 348 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/unistd.h"
int Cyc_execlp(const char*,const char*,struct _dyneither_ptr);
# 359
int execvp(const char*file,const char**argv);
# 375
struct _dyneither_ptr Cyc_getcwd(struct _dyneither_ptr buf,unsigned long size);
# 388
int Cyc_gethostname(struct _dyneither_ptr,unsigned long);
# 443
int Cyc_read(int,struct _dyneither_ptr,unsigned long);
# 493
int Cyc_write(int,struct _dyneither_ptr,unsigned long);static char _tmp87[36]="execlp arg list not NULL-terminated";
# 908 "bin/lib/cyc-lib/i386-portbld-freebsd4.11/include/cycstubs.cyc"
static struct Cyc_Core_Failure_exn_struct Cyc___execlp_failure={Cyc_Core_Failure,{_tmp87,_tmp87,_tmp87 + 36}};int Cyc_execlp(const char*path,const char*arg0,struct _dyneither_ptr argv);static void _tmpBC(unsigned int*_tmpBB,unsigned int*_tmpBA,const char***_tmpB8){for(*_tmpBB=0;*_tmpBB < *_tmpBA;(*_tmpBB)++){(*_tmpB8)[*_tmpBB]=(const char*)0;}}
# 910
int Cyc_execlp(const char*path,const char*arg0,struct _dyneither_ptr argv){
if(*((const char**)_check_dyneither_subscript(argv,sizeof(const char*),(int)(_get_dyneither_size(argv,sizeof(const char*))- 1)))!= (const char*)0)(int)_throw((void*)& Cyc___execlp_failure);{
# 913
struct _RegionHandle _tmp88=_new_region("r2");struct _RegionHandle*r2=& _tmp88;_push_region(r2);
{unsigned int _tmpBB;unsigned int _tmpBA;struct _dyneither_ptr _tmpB9;const char**_tmpB8;unsigned int _tmpB7;struct _dyneither_ptr newargs=
(_tmpB7=_get_dyneither_size(argv,sizeof(const char*)),((_tmpB8=(const char**)_region_malloc(r2,_check_times(sizeof(const char*),_tmpB7 + 1)),((_tmpB9=_tag_dyneither(_tmpB8,sizeof(const char*),_tmpB7 + 1),((((_tmpBA=_tmpB7,((_tmpBC(& _tmpBB,& _tmpBA,& _tmpB8),_tmpB8[_tmpBA]=(const char*)0)))),_tmpB9)))))));
{const char*_tmpBF;const char*_tmpBE;struct _dyneither_ptr _tmpBD;(_tmpBD=_dyneither_ptr_plus(newargs,sizeof(const char*),0),((_tmpBE=*((const char**)_check_dyneither_subscript(_tmpBD,sizeof(const char*),0)),((_tmpBF=arg0,((_get_dyneither_size(_tmpBD,sizeof(const char*))== 1  && (_tmpBE == 0  && _tmpBF != 0)?_throw_arraybounds(): 1,*((const char**)_tmpBD.curr)=_tmpBF)))))));}
{int i=0;for(0;i < _get_dyneither_size(argv,sizeof(const char*))- 1;++ i){
const char*_tmpC2;const char*_tmpC1;struct _dyneither_ptr _tmpC0;(_tmpC0=_dyneither_ptr_plus(newargs,sizeof(const char*),i + 1),((_tmpC1=*((const char**)_check_dyneither_subscript(_tmpC0,sizeof(const char*),0)),((_tmpC2=*((const char**)_check_dyneither_subscript(argv,sizeof(const char*),i)),((_get_dyneither_size(_tmpC0,sizeof(const char*))== 1  && (_tmpC1 == 0  && _tmpC2 != 0)?_throw_arraybounds(): 1,*((const char**)_tmpC0.curr)=_tmpC2)))))));}}{
int _tmp8F=execvp(path,(const char**)_check_null(_untag_dyneither_ptr(newargs,sizeof(const char*),1)));_npop_handler(0);return _tmp8F;};}
# 914
;_pop_region(r2);};}
# 951
char*getcwd(char*buf,unsigned long size);static char _tmp95[29]="getcwd: invalid buf argument";
# 953
static struct Cyc_Core_Failure_exn_struct Cyc___getcwd_failure={Cyc_Core_Failure,{_tmp95,_tmp95,_tmp95 + 29}};
# 955
struct _dyneither_ptr Cyc_getcwd(struct _dyneither_ptr buf,unsigned long size){
if(_get_dyneither_size(buf,sizeof(char))< size)(int)_throw((void*)& Cyc___getcwd_failure);{
char*_tmp96=getcwd((char*)_check_null(_untag_dyneither_ptr(buf,sizeof(char),1)),size);
return(unsigned int)_tmp96?buf: _tag_dyneither(0,0,0);};}
# 962
int gethostname(char*,unsigned long);static char _tmp98[34]="gethostname: called with NULL buf";
# 964
static struct Cyc_Core_Failure_exn_struct Cyc___gethostname_failure_1={Cyc_Core_Failure,{_tmp98,_tmp98,_tmp98 + 34}};static char _tmp9A[46]="gethostname: called with count > numelts(buf)";
# 966
static struct Cyc_Core_Failure_exn_struct Cyc___gethostname_failure_2={Cyc_Core_Failure,{_tmp9A,_tmp9A,_tmp9A + 46}};
# 968
int Cyc_gethostname(struct _dyneither_ptr buf,unsigned long count){
if(!((unsigned int)buf.curr))(int)_throw((void*)& Cyc___gethostname_failure_1);else{
# 971
if(count > _get_dyneither_size(buf,sizeof(char)))(int)_throw((void*)& Cyc___gethostname_failure_2);
return gethostname((char*)_untag_dyneither_ptr(buf,sizeof(char),1),count);}}
# 977
int read(int fd,char*buf,unsigned long count);static char _tmp9C[39]="read: called with count > numelts(buf)";
# 979
static struct Cyc_Core_Failure_exn_struct Cyc___read_failure={Cyc_Core_Failure,{_tmp9C,_tmp9C,_tmp9C + 39}};
# 981
int Cyc_read(int fd,struct _dyneither_ptr buf,unsigned long count){
if(count > _get_dyneither_size(buf,sizeof(char)))(int)_throw((void*)& Cyc___read_failure);
return read(fd,(char*)_check_null(_untag_dyneither_ptr(buf,sizeof(char),1)),count);}
# 987
int write(int fd,const char*buf,unsigned long count);static char _tmp9E[40]="write: called with count > numelts(buf)";
# 989
static struct Cyc_Core_Failure_exn_struct Cyc___write_failure={Cyc_Core_Failure,{_tmp9E,_tmp9E,_tmp9E + 40}};
# 991
int Cyc_write(int fd,struct _dyneither_ptr buf,unsigned long count){
if(count > _get_dyneither_size(buf,sizeof(char)))(int)_throw((void*)& Cyc___write_failure);
return write(fd,(const char*)_untag_dyneither_ptr(buf,sizeof(char),1),count);}struct Cyc_utimbuf{long actime;long modtime;};
